@@ -199,6 +199,10 @@ def SetGamedaysAndHourToken ():
 	GemRB.SetToken ('GAMEDAYS', str (days))
 	GemRB.SetToken ('HOUR', str (hours))
 
+def Gain(infostr, ability):
+	GemRB.SetToken ('SPECIALABILITYNAME', GemRB.GetString(int(ability) ) )
+	GemRB.DisplayString (infostr)
+
 # Adds class/kit abilities
 def AddClassAbilities (pc, table, Level=1, LevelDiff=1, align=-1):
 	TmpTable = GemRB.LoadTable (table)
@@ -233,14 +237,18 @@ def AddClassAbilities (pc, table, Level=1, LevelDiff=1, align=-1):
 					ab = "GA_" + ab
 
 				# apply spell (AP_) or gain spell (GA_)
-				if ab[:2] == "AP":
+				if ab[:3] == "AP_":
 					GemRB.ApplySpell (pc, ab[3:])
-				elif ab[:2] == "GA":
+				elif ab[:3] == "GA_":
 					SpellIndex = Spellbook.HasSpell (pc, IE_SPELL_TYPE_INNATE, 0, ab[3:])
 					if SpellIndex == -1:
 						GemRB.LearnSpell (pc, ab[3:], LS_MEMO)
 					else:
 						GemRB.MemorizeSpell (pc, IE_SPELL_TYPE_INNATE, 0, SpellIndex)
+				elif ab[:3] == "FS_":
+					Gain(26320, ab[3:])
+				elif ab[:3] == "FA_":
+					Gain(10514, ab[3:])
 				else:
 					print "ERROR, unknown class ability (type): ", ab
 
@@ -279,15 +287,15 @@ def RemoveClassAbilities (pc, table, Level):
 					ab = "GA_" + ab
 
 				# apply spell (AP_) or gain spell (GA_)?
-				if ab[:2] == "AP":
+				if ab[:3] == "AP_":
 					GemRB.RemoveEffects (pc, ab[3:])
-				elif ab[:2] == "GA":
+				elif ab[:3] == "GA_":
 					if SpellIndex >= 0:
 						# TODO: get the correct counts to avoid removing an innate ability
 						# given by more than one thing?
 						# RemoveSpell will unmemorize them all too
 						GemRB.RemoveSpell (pc, IE_SPELL_TYPE_INNATE, 0, SpellIndex)
-				else:
+				elif ab[:3] != "FA_" and ab[:3] != "FS_":
 					print "ERROR, unknown class ability (type): ", ab
 
 def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
@@ -295,8 +303,8 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 	Button.SetBorder (0, 0,0,0,0, 128,128,255,64, 0,1)
 	Button.SetBorder (1, 2,2,2,2, 32,32,255,0, 0,0)
 	Button.SetBorder (2, 0,0,0,0, 255,128,128,64, 0,1)
-	Button.SetFlags (IE_GUI_BUTTON_ALIGN_RIGHT | IE_GUI_BUTTON_ALIGN_TOP | IE_GUI_BUTTON_PICTURE, OP_OR)
 	Button.SetText ("")
+	Button.SetFlags (IE_GUI_BUTTON_ALIGN_RIGHT | IE_GUI_BUTTON_ALIGN_BOTTOM | IE_GUI_BUTTON_PICTURE, OP_OR)
 
 	if Slot == None:
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_NAND)
@@ -404,7 +412,7 @@ def GetActorClassTitle (actor):
 		Class = GemRB.GetPlayerStat (actor, IE_CLASS)
 		ClassIndex = CommonTables.Classes.FindValue ( 5, Class )
 		KitIndex = GetKitIndex (actor)
-		Multi = CommonTables.Classes.GetValue (ClassIndex, 4)
+		Multi = HasMultiClassBits (actor)
 		Dual = IsDualClassed (actor, 1)
 
 		if Multi and Dual[0] == 0: # true multi class
@@ -457,6 +465,19 @@ def GetKitIndex (actor):
 
 	return KitIndex
 
+# checks the classes.2da table if the class is multiclass/dualclass capable (bits define the class combination)
+def HasMultiClassBits(actor):
+	Class = GemRB.GetPlayerStat (actor, IE_CLASS)
+	ClassIndex = CommonTables.Classes.FindValue (5, Class)
+	ClassRowName = CommonTables.Classes.GetRowName (ClassIndex)
+	MultiBits = CommonTables.Classes.GetValue (ClassRowName, "MULTI")
+
+	# we have no entries for npc creature classes, so treat them as single-classed
+	if MultiBits == "*":
+		MultiBits = 0
+
+	return MultiBits
+
 def IsDualClassed(actor, verbose):
 	"""Returns an array containing the dual class information.
 
@@ -468,12 +489,14 @@ def IsDualClassed(actor, verbose):
 	if GameIsIWD2():
 		return (0,-1,-1)
 
+	Multi = HasMultiClassBits (actor)
+
+	if Multi == 0:
+		return (0, -1, -1)
+
 	DualedFrom = GemRB.GetPlayerStat (actor, IE_MC_FLAGS) & MC_WAS_ANY_CLASS
 
 	if verbose:
-		Class = GemRB.GetPlayerStat (actor, IE_CLASS)
-		ClassIndex = CommonTables.Classes.FindValue (5, Class)
-		Multi = CommonTables.Classes.GetValue (ClassIndex, 4)
 		DualInfo = []
 		KitIndex = GetKitIndex (actor)
 
@@ -500,7 +523,7 @@ def IsDualClassed(actor, verbose):
 				Mask = 1 << i
 			if len(DualInfo) != 3:
 				print "WARNING: Invalid dualclass combination, treating as a single class!"
-				print DualedFrom, Class, Multi, KitIndex, DualInfo
+				print DualedFrom, Multi, KitIndex, DualInfo
 				return (0,-1,-1)
 
 			return DualInfo
@@ -565,7 +588,7 @@ def IsMultiClassed (actor, verbose):
 
 	# get our base class
 	ClassIndex = CommonTables.Classes.FindValue (5, GemRB.GetPlayerStat (actor, IE_CLASS))
-	IsMulti = CommonTables.Classes.GetValue (ClassIndex, 4) # 0 if not multi'd
+	IsMulti = HasMultiClassBits (actor)
 	IsDual = IsDualClassed (actor, 0)
 
 	# dual-class char's look like multi-class chars
@@ -650,10 +673,12 @@ def CanDualClass(actor):
 		return 1
 
 	AlignmentTable = GemRB.LoadTable ("alignmnt")
-	AlignsTable = GemRB.LoadTable ("aligns")
 	Alignment = GemRB.GetPlayerStat (actor, IE_ALIGNMENT)
-	AlignmentColName = AlignsTable.FindValue (3, Alignment)
-	AlignmentColName = AlignsTable.GetValue (AlignmentColName, 4)
+	AlignmentColName = CommonTables.Aligns.FindValue (3, Alignment)
+	AlignmentColName = CommonTables.Aligns.GetValue (AlignmentColName, 4)
+	if AlignmentColName == -1:
+		print "CannotDualClass: extraordinary character alignment"
+		return 1
 	Sum = 0
 	for classy in matches:
 		Sum += AlignmentTable.GetValue (classy, AlignmentColName)
@@ -784,6 +809,16 @@ def SetCurrentDateTokens (stat):
 
 	return (days, hours)
 
+# gray out window or mark it as visible depending on the actor's state
+# Always greys it out for actors that are: dead, berserking
+# The third parameter is another check which must be 0 to maintain window visibility
+def AdjustWindowVisibility (Window, pc, additionalCheck):
+	if not additionalCheck and GemRB.ValidTarget (pc, GA_SELECT|GA_NO_DEAD):
+		Window.SetVisible (WINDOW_VISIBLE)
+	else:
+		Window.SetVisible (WINDOW_GRAYED)
+	return
+
 # return ceil(n/d)
 # 
 def ceildiv (n, d):
