@@ -1091,7 +1091,15 @@ def OpenPortraitWindow (needcontrols=0):
 
 	for i in range (PARTY_SIZE):
 		Button = Window.GetControl (i)
-		Button.SetFont ("STATES2")
+		if GUICommon.GameIsIWD1() or GUICommon.GameIsIWD2():
+			Button.SetFont ("STATES")
+			# label for status flags (dialog, store, level up)
+			Button.CreateLabelOnButton(200 + i, "STATES", IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_RIGHT) #level up icon is on the right
+		else:
+			Button.SetFont ("STATES2")
+			# label for status flags (dialog, store, level up)
+			Button.CreateLabelOnButton(200 + i, "STATES2", IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_RIGHT) #level up icon is on the right
+
 		Button.SetVarAssoc ("PressedPortrait", i+1)
 
 		if needcontrols or GUICommon.GameIsIWD2():
@@ -1107,15 +1115,22 @@ def OpenPortraitWindow (needcontrols=0):
 		Button.SetEvent (IE_GUI_MOUSE_ENTER_BUTTON, PortraitButtonOnMouseEnter)
 		Button.SetEvent (IE_GUI_MOUSE_LEAVE_BUTTON, PortraitButtonOnMouseLeave)
 
+		Label = Window.GetControl(200 + i)
 		if GUICommon.GameIsIWD1():
 			# overlay a label, so we can display the hp with the correct font. Regular button label
 			#   is used by effect icons
-			Button.CreateLabelOnButton(100+i, "NUMFONT", IE_GUI_BUTTON_ALIGN_TOP|IE_GUI_BUTTON_ALIGN_LEFT)
+			Button.CreateLabelOnButton(100+i, "NUMFONT", IE_FONT_ALIGN_TOP|IE_FONT_ALIGN_LEFT)
 			HPLabel = Window.GetControl (100+i)
 			HPLabel.SetUseRGB (True)
 
-		Button.SetBorder (FRAME_PC_SELECTED, 1, 1, 2, 2, 0, 255, 0, 255)
-		Button.SetBorder (FRAME_PC_TARGET, 3, 3, 4, 4, 255, 255, 0, 255)
+		# unlike other buttons, this one lacks extra frames for a selection effect
+		# so we create it and shift it to cover the grooves of the image
+		# except iwd2's second frame already has it incorporated (but we miscolor it)
+		if GUICommon.GameIsIWD2():
+			Button.SetBorder (FRAME_PC_SELECTED, 0, 0, 0, 0, 0, 255, 0, 255)
+		else:
+			Button.SetBorder (FRAME_PC_SELECTED, 4, 3, 4, 3, 0, 255, 0, 255)
+		Button.SetBorder (FRAME_PC_TARGET, 2, 2, 3, 3, 255, 255, 0, 255)
 
 	UpdatePortraitWindow ()
 	SelectionChanged ()
@@ -1148,47 +1163,26 @@ def UpdatePortraitWindow ():
 			Button.SetTooltip ("")
 			continue
 
-		portraitFlags = IE_GUI_BUTTON_PICTURE| IE_GUI_BUTTON_HORIZONTAL| \
-			IE_GUI_BUTTON_ALIGN_LEFT| IE_GUI_BUTTON_DRAGGABLE|IE_GUI_BUTTON_MULTILINE
+		portraitFlags = IE_GUI_BUTTON_PICTURE | IE_GUI_BUTTON_HORIZONTAL | IE_GUI_BUTTON_ALIGN_LEFT | \
+						IE_GUI_BUTTON_DRAGGABLE | IE_GUI_BUTTON_MULTILINE | IE_GUI_BUTTON_ALIGN_BOTTOM
 		if GUICommon.GameIsIWD2():
-			portraitFlags |= IE_GUI_BUTTON_ALIGN_BOTTOM
 			Button.SetEvent (IE_GUI_BUTTON_ON_RIGHT_PRESS, GUIINV.OpenInventoryWindowClick)
 			Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, PortraitButtonOnPress)
-		else:
-			portraitFlags |= IE_GUI_BUTTON_ALIGN_TOP
+
 		Button.SetFlags (portraitFlags, OP_SET)
 
 		Button.SetState (IE_GUI_BUTTON_LOCKED)
 		Button.SetPicture (pic, "NOPORTSM")
 		ratio_str, color = GUICommon.SetupDamageInfo (portid+1, Button, Window)
 
-		#add effects on the portrait
-		effects = GemRB.GetPlayerStates (portid+1)
-
-		states = ""
-		for col in range(len(effects)):
-			states = effects[col:col+1] + states
-			if col % 3 == 2: states = "\n" + states
-		for x in range(3 - (len(effects)/3)):
-			states = "\n" + states
-		states = "\n" + states
-
 		# character - 1 == bam cycle
-		# blank space
+		talk = store = flag = blank = ""
 		if GUICommon.GameIsBG2():
+			# as far as I can tell only BG2 has icons for talk or store
 			flag = blank = chr(238)
-			talk = 154
-			store = 155
-		elif GUICommon.GameIsIWD2():
-			talk = store = flag = blank = ""
-		else:
-			# iwd is missing all of these, including the blank (didn't display a talking icon though)
-			# TODO: add another string tag to make glyphs 100% transparent?
-			flag = blank = chr(33)
-			talk = store = 37
+			talk = 154 # dialog icon
+			store = 155 # shopping icon
 
-		if not GUICommon.GameIsIWD1():
-			# shopping icon
 			if pc==portid+1:
 				if GemRB.GetStore()!=None:
 					flag = chr(store)
@@ -1197,14 +1191,33 @@ def UpdatePortraitWindow ():
 				flag = chr(talk)
 
 		if LUCommon.CanLevelUp (portid+1):
-			states = flag+blank+chr(255) + states
+			flag = flag + blank + chr(255)
+		elif GUICommon.GameIsIWD1():
+			HPLabel = Window.GetControl (100+portid)
+			HPLabel.SetText (ratio_str) # TODO: color depending on the ratio
+			HPLabel.SetTextColor (*color)
+
+		#add effects on the portrait
+		effects = GemRB.GetPlayerStates (portid+1)
+
+		numCols = 4 if GUICommon.GameIsIWD2() else 3
+		numEffects = len(effects)
+
+		states = ""
+		# calculate the partial row
+		idx = numEffects % numCols
+		states = effects[0:idx] + "\n"
+
+		for x in range(idx, numEffects): # now do any rows that are full
+			states = states + effects[x]
+			if (x - idx) % numCols == numCols - 1:
+				states = states + "\n"
+
+		FlagLabel = Window.GetControl(200 + portid)
+		if flag != blank:
+			FlagLabel.SetText(flag)
 		else:
-			if GUICommon.GameIsIWD1():
-				HPLabel = Window.GetControl (100+portid)
-				HPLabel.SetText (ratio_str) # TODO: color depending on the ratio
-				HPLabel.SetTextColor (*color)
-			else:
-				states = flag+blank+blank + states
+			FlagLabel.SetText("")
 		Button.SetText(states)
 	return
 
