@@ -263,12 +263,13 @@ def UpdateRecordsWindow ():
 	Label = Window.GetControl (0x1000000f)
 	Label.SetText (text)
 
-	Table = GemRB.LoadTable ("aligns")
-
-	text = Table.GetValue (Table.FindValue ( 3, GemRB.GetPlayerStat (pc, IE_ALIGNMENT) ), 0)
+	# alignment
+	text = CommonTables.Aligns.FindValue (3, GemRB.GetPlayerStat (pc, IE_ALIGNMENT))
+	text = CommonTables.Aligns.GetValue (text, 0)
 	Label = Window.GetControl (0x10000010)
 	Label.SetText (text)
 
+	# gender
 	Label = Window.GetControl (0x10000011)
 	if GemRB.GetPlayerStat (pc, IE_SEX) == 1:
 		Label.SetText (7198)
@@ -320,6 +321,8 @@ def GetStatOverview (pc, LevelDiff=[0,0,0]):
 		str_None = GemRB.GetString (17093)
 
 	stats = []
+	cdet = GemRB.GetCombatDetails(pc, 0)
+
 	# class levels
 	# 16480 <CLASS>: Level <LEVEL>
 	# Experience: <EXPERIENCE>
@@ -446,18 +449,20 @@ def GetStatOverview (pc, LevelDiff=[0,0,0]):
 	stats.append ( (8442,1,'c') )
 
 	# look ma, I can use both hands
+	
 	if GUICommon.GameIsBG2():
 		stats.append ( (61932, GS (IE_TOHIT), '0') )
 		if (GemRB.IsDualWielding(pc)):
-			stats.append ( (56911, GemRB.GetCombatDetails(pc, 0)["ToHit"], '0') )
+			stats.append ( (56911, cdet["ToHit"], '0') )
 			stats.append ( (56910, GemRB.GetCombatDetails(pc, 1)["ToHit"], '0') )
 		else:
-			stats.append ( (9457, GemRB.GetCombatDetails(pc, 0)["ToHit"], '0') )
+			stats.append ( (9457, cdet["ToHit"], '0') )
 	else:
-		stats.append ( (9457, str(GS (IE_TOHIT))+" ("+str(GemRB.GetCombatDetails(pc, 0)["ToHit"])+")", '0') )
-	tmp = GS (IE_NUMBEROFATTACKS)
+		stats.append ( (9457, str(GS (IE_TOHIT))+" ("+str(cdet["ToHit"])+")", '0') )
+
+	tmp = cdet["APR"]
 	if (tmp&1):
-		tmp2 = str (tmp/2) + chr (188)
+		tmp2 = str (tmp/2) + chr (189) #must use one higher than the frame count
 	else:
 		tmp2 = str (tmp/2)
 	stats.append ( (9458, tmp2, '') )
@@ -598,22 +603,34 @@ def GetStatOverview (pc, LevelDiff=[0,0,0]):
 	else:
 		stats.append (32204)
 	# 32213 Normal Fire
-	stats.append ((32213, GS (IE_RESISTFIRE), '%'))
 	# 32222 Magic Fire
 	# 32214 Normal Cold
 	# 32223 Magic Cold
 	if GUICommon.GameIsBG2():
+		stats.append ((32213, GS (IE_RESISTFIRE), '%'))
 		stats.append ((32222, GS (IE_RESISTMAGICFIRE), '%'))
 		stats.append ((32214, GS (IE_RESISTCOLD), '%'))
 		stats.append ((32223, GS (IE_RESISTMAGICCOLD), '%'))
+	elif GUICommon.GameIsBG1():
+		stats.append ((14012, GS (IE_RESISTFIRE), '%'))
+		stats.append ((14077, GS (IE_RESISTMAGICFIRE), '%'))
+		stats.append ((14014, GS (IE_RESISTCOLD), '%'))
+		stats.append ((14078, GS (IE_RESISTMAGICCOLD), '%'))
 	else:
+		stats.append ((15545, GS (IE_RESISTFIRE), '%'))
 		stats.append ((15579, GS (IE_RESISTMAGICFIRE), '%'))
 		stats.append ((15546, GS (IE_RESISTCOLD), '%'))
 		stats.append ((15580, GS (IE_RESISTMAGICCOLD), '%'))
 	# 32220 Electricity
-	stats.append ((32220, GS (IE_RESISTELECTRICITY), '%'))
+	if GUICommon.GameIsBG1():
+		stats.append ((14013, GS (IE_RESISTELECTRICITY), '%'))
+	else:
+		stats.append ((32220, GS (IE_RESISTELECTRICITY), '%'))
 	# 32221 Acid
-	stats.append ((32221, GS (IE_RESISTACID), '%'))
+	if GUICommon.GameIsBG1():
+		stats.append ((14015, GS (IE_RESISTACID), '%'))
+	else:
+		stats.append ((32221, GS (IE_RESISTACID), '%'))
 	if GUICommon.GameIsBG2():
 		# Magic (others show it higher up)
 		stats.append ((62146, GS (IE_RESISTMAGIC), '%'))
@@ -637,7 +654,7 @@ def GetStatOverview (pc, LevelDiff=[0,0,0]):
 	if GUICommon.GameIsBG2():
 		# Weapon Style bonuses
 		stats.append (32131)
-		wstyle = GemRB.GetCombatDetails (pc, 0)["Style"] # equipped weapon style + 1000 * proficiency level
+		wstyle = cdet["Style"] # equipped weapon style + 1000 * proficiency level
 		profcount = wstyle / 1000
 		if profcount:
 			wstyletables = { IE_PROFICIENCY2WEAPON:"wstwowpn", IE_PROFICIENCY2HANDED:"wstwohnd", IE_PROFICIENCYSINGLEWEAPON:"wssingle", IE_PROFICIENCYSWORDANDSHIELD:"wsshield" }
@@ -850,7 +867,7 @@ def OpenKitInfoWindow ():
 	pc = GemRB.GameGetSelectedPCSingle ()
 	Class = GemRB.GetPlayerStat (pc, IE_CLASS)
 	ClassIndex = CommonTables.Classes.FindValue (5, Class)
-	Multi = CommonTables.Classes.GetValue (ClassIndex, 4)
+	Multi = GUICommon.HasMultiClassBits (pc)
 	Dual = GUICommon.IsDualClassed (pc, 1)
 
 	if Multi and Dual[0] == 0: # true multi class
