@@ -202,6 +202,19 @@ Classes = [IE_LEVELBARBARIAN, IE_LEVELBARD, IE_LEVELCLERIC, IE_LEVELDRUID, \
 IE_LEVEL, IE_LEVELMONK, IE_LEVELPALADIN, IE_LEVELRANGER, IE_LEVEL3, \
 IE_LEVELSORCEROR, IE_LEVEL2]
 
+def DisplayCommon (pc):
+	Window = RecordsWindow
+
+	Value = GemRB.GetPlayerStat(pc,IE_RACE)
+	Value2 = GemRB.GetPlayerStat(pc,IE_SUBRACE)
+	if Value2:
+		Value = Value<<16 | Value2
+	tmp = CommonTables.Races.FindValue (3, Value)
+	Race = CommonTables.Races.GetValue (tmp, 2)
+	Label = Window.GetControl (0x1000000f)
+	Label.SetText (Race)
+	return
+
 # screenshots at http:// lparchive.org/Icewind-Dale-2/Update%2013/
 def DisplayGeneral (pc):
 	Window = RecordsWindow
@@ -238,7 +251,6 @@ def DisplayGeneral (pc):
 
 	#favoured class
 	RecordsTextArea.Append (40310,-1)
-	AlignTable = GemRB.LoadTable("aligns")
 
 	#get the subrace value
 	Value = GemRB.GetPlayerStat(pc,IE_RACE)
@@ -249,9 +261,6 @@ def DisplayGeneral (pc):
 	Race = CommonTables.Races.GetValue (tmp, 2)
 	tmp = CommonTables.Races.GetValue (tmp, 8)
 
-	Label = Window.GetControl (0x1000000f)
-	Label.SetText (Race)
-
 	if tmp == -1:
 		tmp = highest
 	else:
@@ -296,8 +305,8 @@ def DisplayGeneral (pc):
 	RecordsTextArea.Append ("\n\n[color=ffff00]")
 	RecordsTextArea.Append (1049)
 	RecordsTextArea.Append ("[/color]")
-	tmp = AlignTable.FindValue ( 3, GemRB.GetPlayerStat (pc, IE_ALIGNMENT) )
-	Align = AlignTable.GetValue (tmp, 2)
+	tmp = CommonTables.Aligns.FindValue (3, GemRB.GetPlayerStat (pc, IE_ALIGNMENT))
+	Align = CommonTables.Aligns.GetValue (tmp, 2)
 	RecordsTextArea.Append (Align,-1)
 
 	#saving throws
@@ -327,10 +336,10 @@ def DisplayGeneral (pc):
 	if HasClassFeatures(pc):
 		RecordsTextArea.Append ("\n\n[color=ffff00]")
 		RecordsTextArea.Append (40314)
-		RecordsTextArea.Append ("[/color]\n")
+		RecordsTextArea.Append ("[/color]")
 		tmp = GemRB.GetPlayerStat (pc, IE_TURNUNDEADLEVEL)
 		if tmp:
-			RecordsTextArea.Append (12146,-1)
+			RecordsTextArea.Append (12126,-1)
 			RecordsTextArea.Append (": "+str(tmp) )
 		tmp = GemRB.GetPlayerStat (pc, IE_BACKSTABDAMAGEMULTIPLIER)
 		if tmp:
@@ -384,13 +393,12 @@ def DisplayWeapons (pc):
 	RecordsTextArea.Append ("[/color]\n")
 
 	combatdet = GemRB.GetCombatDetails(pc, 0)
-	numOfAttacks = GS (IE_NUMBEROFATTACKS)//2
 
 	# Main Hand
 	# display all the (successive) attack values (+15/+10/+5)
 	total = combatdet["ToHit"]
 	tmpstr = str(total)
-	for i in range(1, numOfAttacks):
+	for i in range(1, combatdet["APR"]//2):
 		tmpstr = tmpstr  + "/" + str(total-i*5)
 	RecordsTextArea.Append (delimited_txt (734, ":", tmpstr, 0))
 	# Base
@@ -435,7 +443,7 @@ def DisplayWeapons (pc):
 
 	###################
 	# Number of Attacks
-	RecordsTextArea.Append (delimited_txt (9458, ":", str (numOfAttacks)))
+	RecordsTextArea.Append (delimited_txt (9458, ":", str (combatdet["APR"]//2)))
 	RecordsTextArea.Append ("\n")
 
 	###################
@@ -801,6 +809,8 @@ def UpdateRecordsWindow ():
 	RecordsTextArea.SetText ("")
 	RecordsTextArea.Append ("[capital=0]")
 
+	DisplayCommon (pc)
+
 	SelectWindow = GemRB.GetVar ("SelectWindow")
 	if SelectWindow == 1:
 		DisplayGeneral (pc)
