@@ -103,7 +103,7 @@ void Button::SetImage(unsigned char type, Sprite2D* img)
 			Unpressed = img;
 			break;
 
-		case IE_GUI_BUTTON_SECOND:
+		case IE_GUI_BUTTON_FAKEPRESSED:
 		case IE_GUI_BUTTON_PRESSED:
 			core->GetVideoDriver()->FreeSprite( Pressed );
 			Pressed = img;
@@ -115,7 +115,7 @@ void Button::SetImage(unsigned char type, Sprite2D* img)
 			break;
 
 		case IE_GUI_BUTTON_DISABLED:
-		case IE_GUI_BUTTON_THIRD:
+		case IE_GUI_BUTTON_FAKEDISABLED:
 			core->GetVideoDriver()->FreeSprite( Disabled );
 			Disabled = img;
 			break;
@@ -180,7 +180,7 @@ void Button::Draw(unsigned short x, unsigned short y)
 				Image = Unpressed;
 				break;
 
-			case IE_GUI_BUTTON_SECOND:
+			case IE_GUI_BUTTON_FAKEPRESSED:
 			case IE_GUI_BUTTON_PRESSED:
 				Image = Pressed;
 				if (! Image)
@@ -194,7 +194,7 @@ void Button::Draw(unsigned short x, unsigned short y)
 				break;
 
 			case IE_GUI_BUTTON_DISABLED:
-			case IE_GUI_BUTTON_THIRD:
+			case IE_GUI_BUTTON_FAKEDISABLED:
 				Image = Disabled;
 				if (! Image)
 					Image = Unpressed;
@@ -216,13 +216,27 @@ void Button::Draw(unsigned short x, unsigned short y)
 	}
 
 	// Button picture
+	if (AnimPicture) {
+		int xOffs = ( Width / 2 ) - ( AnimPicture->Width / 2 );
+		int yOffs = ( Height / 2 ) - ( AnimPicture->Height / 2 );
+		Region r( x + XPos + xOffs, y + YPos + yOffs, (int)(AnimPicture->Width * Clipping), AnimPicture->Height );
+
+		if (Flags & IE_GUI_BUTTON_CENTER_PICTURES) {
+			video->BlitSprite( AnimPicture, x + XPos + xOffs + AnimPicture->XPos, y + YPos + yOffs + AnimPicture->YPos, true, &r );
+		} else {
+			video->BlitSprite( AnimPicture, x + XPos + xOffs, y + YPos + yOffs, true, &r );
+		}
+	}
+
+	// Button picture
+	int picXPos = 0, picYPos = 0;
 	if (Picture  && (Flags & IE_GUI_BUTTON_PICTURE) ) {
 		// Picture is drawn centered
-		int xOffs = ( Width / 2 ) - ( Picture->Width / 2 );
-		int yOffs = ( Height / 2 ) - ( Picture->Height / 2 );
+		picXPos = ( Width / 2 ) - ( Picture->Width / 2 ) + x + XPos;
+		picYPos = ( Height / 2 ) - ( Picture->Height / 2 ) + y + YPos;
 		if (Flags & IE_GUI_BUTTON_HORIZONTAL) {
-			xOffs += x + XPos + Picture->XPos;
-			yOffs += y + YPos + Picture->YPos;
+			picXPos += Picture->XPos;
+			picYPos += Picture->YPos;
 
 			// Clipping: 0 = overlay over full button, 1 = no overlay
 			int overlayHeight = Picture->Height * (1.0 - Clipping);
@@ -232,21 +246,21 @@ void Button::Draw(unsigned short x, unsigned short y)
 				overlayHeight = Picture->Height;
 			int buttonHeight = Picture->Height - overlayHeight;
 
-			Region rb = Region(xOffs, yOffs, Picture->Width, buttonHeight);
-			Region ro = Region(xOffs, yOffs + buttonHeight, Picture->Width, overlayHeight);
+			Region rb = Region(picXPos, picYPos, Picture->Width, buttonHeight);
+			Region ro = Region(picXPos, picYPos + buttonHeight, Picture->Width, overlayHeight);
 
-			video->BlitSprite( Picture, xOffs, yOffs, true, &rb );
+			video->BlitSprite( Picture, picXPos, picYPos, true, &rb );
 
 			// TODO: Add an option to add BLIT_GREY to the flags
-			video->BlitGameSprite( Picture, xOffs, yOffs, BLIT_TINTED, SourceRGB, 0, 0, &ro, true);
+			video->BlitGameSprite( Picture, picXPos, picYPos, BLIT_TINTED, SourceRGB, 0, 0, &ro, true);
 
 			// do NOT uncomment this, you can't change Changed or invalidate things from
 			// the middle of Window::DrawWindow() -- it needs moving to somewhere else
 			//CloseUpColor();
 		}
 		else {
-			Region r( x + XPos + xOffs, y + YPos + yOffs, (int)(Picture->Width * Clipping), Picture->Height );
-			video->BlitSprite( Picture, x + XPos + xOffs + Picture->XPos, y + YPos + yOffs + Picture->YPos, true, &r );
+			Region r( picXPos, picYPos, (int)(Picture->Width * Clipping), Picture->Height );
+			video->BlitSprite( Picture, picXPos + Picture->XPos, picYPos + Picture->YPos, true, &r );
 		}
 	}
 
@@ -273,19 +287,6 @@ void Button::Draw(unsigned short x, unsigned short y)
 		}
 	}
 
-	// Button picture
-	if (AnimPicture) {
-		int xOffs = ( Width / 2 ) - ( AnimPicture->Width / 2 );
-		int yOffs = ( Height / 2 ) - ( AnimPicture->Height / 2 );
-		Region r( x + XPos + xOffs, y + YPos + yOffs, (int)(AnimPicture->Width * Clipping), AnimPicture->Height );
-
-		if (Flags & IE_GUI_BUTTON_CENTER_PICTURES) {
-			video->BlitSprite( AnimPicture, x + XPos + xOffs + AnimPicture->XPos, y + YPos + yOffs + AnimPicture->YPos, true, &r );
-		} else {
-			video->BlitSprite( AnimPicture, x + XPos + xOffs, y + YPos + yOffs, true, &r );
-		}
-	}
-
 	// Button label
 	if (hasText && ! ( Flags & IE_GUI_BUTTON_NO_TEXT )) {
 		Palette* ppoi = normal_palette;
@@ -314,9 +315,18 @@ void Button::Draw(unsigned short x, unsigned short y)
 		if (! (Flags & IE_GUI_BUTTON_MULTILINE)) {
 			align |= IE_FONT_SINGLE_LINE;
 		}
-		font->Print( Region( x + XPos, y + YPos, Width - 2, Height - 2),
-			( unsigned char * ) Text, ppoi,
-			(ieByte) align, true );
+
+		Region r;
+		if (Picture && (Flags & IE_GUI_BUTTON_PORTRAIT) == IE_GUI_BUTTON_PORTRAIT) {
+			// constrain the label (status icons) to the picture bounds
+			// we are subtracting IE_FONT_PADDING because Font indents 5px, but we dont want that here
+			r = Region(picXPos - IE_FONT_PADDING, picYPos + IE_FONT_PADDING,
+					   Picture->Width + IE_FONT_PADDING, Picture->Height);
+		} else {
+			r = Region( x + XPos, y + YPos, Width - 2, Height - 2);
+		}
+
+		font->Print( r, ( unsigned char * ) Text, ppoi, (ieByte) align, true );
 	}
 
 	if (! (Flags&IE_GUI_BUTTON_NO_IMAGE)) {
@@ -622,9 +632,9 @@ void Button::SetText(const char* string)
 	} else {
 		Text = strndup( string, 255 );
 		if (Flags&IE_GUI_BUTTON_LOWERCASE)
-			strlwr( Text );
+			strtolower( Text );
 		else if (Flags&IE_GUI_BUTTON_CAPS)
-			strupr( Text );
+			strtoupper( Text );
 		hasText = true;
 	}
 	Changed = true;
