@@ -314,7 +314,7 @@ static const int arrow_orientations[16]={
 
 //Draws arrow markers along the edge of the game window
 //WARNING:don't use reference for point, because it is altered
-void GameControl::DrawArrowMarker(const Region &screen, Point p, const Region &viewport)
+void GameControl::DrawArrowMarker(const Region &screen, Point p, const Region &viewport, const Color& color)
 {
 	Video* video = core->GetVideoDriver();
 
@@ -349,7 +349,7 @@ void GameControl::DrawArrowMarker(const Region &screen, Point p, const Region &v
 		draw |= D_BOTTOM;
 	}
 	if (arrow_orientations[draw]>=0) {
-		video->BlitGameSprite( core->GetScrollCursorSprite(arrow_orientations[draw], 0), p.x+screen.x, p.y+screen.y, 0, black, NULL);
+		video->BlitGameSprite( core->GetScrollCursorSprite(arrow_orientations[draw], 0), p.x+screen.x, p.y+screen.y, BLIT_TINTED, color, NULL);
 	}
 }
 
@@ -554,7 +554,7 @@ void GameControl::Draw(unsigned short x, unsigned short y)
 				Actor *target = monsters[i++];
 				if (target->InParty) continue;
 				if (target->GetStat(IE_NOTRACKING)) continue;
-				DrawArrowMarker(screen, target->Pos, viewport);
+				DrawArrowMarker(screen, target->Pos, viewport, black);
 			}
 			delete monsters;
 		} else {
@@ -562,6 +562,13 @@ void GameControl::Draw(unsigned short x, unsigned short y)
 		}
 	}
 
+	if (lastActorID) {
+		Actor* actor = GetLastActor();
+		if (actor) {
+			DrawArrowMarker(screen, actor->Pos, viewport, green);
+		}
+	}
+
 	if (ScreenFlags & SF_DISABLEMOUSE)
 		return;
 	Point p(lastMouseX, lastMouseY);
@@ -760,14 +767,17 @@ void GameControl::SelectActor(int whom, int type)
 	}
 	if (type==1) {
 		game->SelectActor( actor, true, SELECT_NORMAL );
+		actor->PlaySelectionSound();
 		return;
 	}
 
 	bool was_selected = actor->IsSelected();
-	if (game->SelectActor( actor, true, SELECT_REPLACE ))
+	if (game->SelectActor( actor, true, SELECT_REPLACE )) {
 		if (was_selected || (ScreenFlags & SF_ALWAYSCENTER)) {
 			ScreenFlags |= SF_CENTERONACTOR;
 		}
+		actor->PlaySelectionSound();
+	}
 }
 
 //Effect for the ctrl-r cheatkey (resurrect)
@@ -2074,7 +2084,7 @@ void GameControl::OnMouseUp(unsigned short x, unsigned short y, unsigned short B
 	if (Button == GEM_MB_MENU && (!core->HasFeature(GF_HAS_FLOAT_MENU) || Mod)) {
 		if (actor) {
 			//play select sound on right click on actor
-			actor->SelectActor();
+			actor->PlaySelectionSound();
 			return;
 		}
 		// reset the action bar
@@ -2210,7 +2220,7 @@ void GameControl::OnMouseUp(unsigned short x, unsigned short y, unsigned short B
 	//we got an actor past this point
 	if (target_mode == TARGET_MODE_NONE) {
 		//play select sound
-		actor->SelectActor();
+		actor->PlaySelectionSound();
 	}
 
 	PerformActionOn(actor);
@@ -2394,7 +2404,6 @@ void GameControl::OnSpecialKeyPress(unsigned char Key)
 	int pm;
 	ieDword keyScrollSpd = 64;
 	core->GetDictionary()->Lookup("Keyboard Scroll Speed", keyScrollSpd);
-	char tmpstr[10];
 	switch (Key) {
 		case GEM_LEFT:
 			OnMouseWheelScroll(keyScrollSpd * -1, 0);
@@ -2416,12 +2425,7 @@ void GameControl::OnSpecialKeyPress(unsigned char Key)
 			for (pm=0; pm < partysize; pm++) {
 				Actor *pc = game->GetPC(pm, true);
 				if (!pc) continue;
-				//sucks but this is set in different places
-				if (pc->GetStat(IE_MC_FLAGS) & MC_HIDE_HP) continue;
-				if (pc->GetStat(IE_EXTSTATE_ID) & EXTSTATE_NO_HP) continue;
-				memset(tmpstr, 0, 10);
-				snprintf(tmpstr, 10, "%d/%d", pc->Modified[IE_HITPOINTS], pc->Modified[IE_MAXHITPOINTS]);
-				pc->DisplayHeadText(strdup(tmpstr));
+				pc->DisplayHeadHPRatio();
 			}
 			return;
 		case GEM_MOUSEOUT:
@@ -2743,6 +2747,7 @@ void GameControl::ResizeAdd(Window* win, int type)
 }
 
 //Create an overhead text over an arbitrary point
+// UNUSED
 void GameControl::DisplayString(const Point &p, const char *Text)
 {
 	Scriptable* scr = new Scriptable( ST_TRIGGER );
@@ -2766,6 +2771,14 @@ void GameControl::DisplayString(Scriptable* target)
 	scr->textDisplaying = 1;
 	scr->timeStartDisplaying = target->timeStartDisplaying;
 	scr->Pos = target->Pos;
+
+	// add as a "subtitle" to the main message window
+	ieDword tmp = 0;
+	core->GetDictionary()->Lookup("Duplicate Floating Text", tmp);
+	if (tmp) {
+		// pass NULL target so pst does not display multiple
+		displaymsg->DisplayString(target->overHeadText, NULL);
+	}
 }
 
 /** changes displayed map to the currently selected PC */
