@@ -95,10 +95,7 @@ void TextArea::RefreshSprite(const char *portrait)
 		SetAnimPicture(NULL);
 	}
 	strnlwrcpy(PortraitResRef, portrait, 8);
-	if (!strnicmp(PortraitResRef, "none", 8) ) {
-		return;
-	}
-	ResourceHolder<ImageMgr> im(PortraitResRef);
+	ResourceHolder<ImageMgr> im(PortraitResRef, true);
 	if (im == NULL) {
 		return;
 	}
@@ -451,11 +448,17 @@ void TextArea::UpdateControls()
 			SetRow(pos);
 		}
 	}
-	// This hack is to refresh the mouse cursor so that reply below cursor gets
-	//   highlighted during a dialog
-	int x,y;
-	core->GetVideoDriver()->GetMousePos(x,y);
-	core->GetEventMgr()->MouseMove(x,y);
+
+	GameControl* gc = core->GetGameControl();
+	if (gc && gc->GetDialogueFlags()&DF_IN_DIALOG) {
+		// This hack is to refresh the mouse cursor so that reply below cursor gets
+		// highlighted during a dialog
+		// FIXME: we check DF_IN_DIALOG here to avoid recurssion in the MessageWindowLogger, but what happens when an error happens during dialog?
+		// I'm not super sure about how to avoid that. for now the logger will not log anything in dialog mode.
+		int x,y;
+		core->GetVideoDriver()->GetMousePos(x,y);
+		core->GetEventMgr()->MouseMove(x,y);
+	}
 
 	core->RedrawAll();
 }
@@ -967,14 +970,12 @@ void TextArea::Clear()
 
 //setting up the textarea for smooth scrolling, the first
 //TEXTAREA_OUTOFTEXT callback is called automatically
-void TextArea::SetupScroll(unsigned long tck)
+void TextArea::SetupScroll()
 {
-	/*
-	tck=number of ticks in which it takes to scroll 1 line
-	*/
 	SetPreservedRow(0);
 	startrow = 0;
-	ticks = tck;
+	// ticks is the number of ticks it takes to scroll this font 1 px
+	ticks = 2000 / ftext->maxHeight; // 2000 is just a value based off the previous magic number.
 	//clearing the textarea
 	Clear();
 	unsigned int i = (unsigned int) (Height/ftext->maxHeight);
