@@ -512,7 +512,7 @@ int CanSee(Scriptable* Sender, Scriptable* target, bool range, int seeflag)
 	if (target->Type==ST_ACTOR) {
 		Actor *tar = (Actor *) target;
 
-		if (!tar->ValidTarget(seeflag)) {
+		if (!tar->ValidTarget(seeflag, Sender)) {
 			return 0;
 		}
 	}
@@ -539,7 +539,7 @@ int CanSee(Scriptable* Sender, Scriptable* target, bool range, int seeflag)
 		}
 	}
 
-	return map->IsVisible(target->Pos, Sender->Pos);
+	return map->IsVisibleLOS(target->Pos, Sender->Pos);
 }
 
 //non actors can see too (reducing function to LOS)
@@ -547,12 +547,12 @@ int CanSee(Scriptable* Sender, Scriptable* target, bool range, int seeflag)
 int SeeCore(Scriptable* Sender, Trigger* parameters, int justlos)
 {
 	//see dead
-	int flags;
+	int flags = 0;
 
 	if (parameters->int0Parameter) {
-		flags = GA_DETECT;
+		flags |= GA_DETECT;
 	} else {
-		flags = GA_NO_DEAD;
+		flags |= GA_NO_DEAD;
 	}
 	Scriptable* tar = GetActorFromObject( Sender, parameters->objectParameter, flags );
 	/* don't set LastSeen if this isn't an actor */
@@ -566,12 +566,17 @@ int SeeCore(Scriptable* Sender, Trigger* parameters, int justlos)
 		return 0;
 	}
 
+	// ignore invisible targets for direct matching
+	if (! parameters->int0Parameter) {
+		flags |= GA_NO_HIDDEN;
+	}
+	
 	//both are actors
 	if (CanSee(Sender, tar, true, flags) ) {
 		if (justlos) {
 			return 1;
 		}
-		if (Sender->Type==ST_ACTOR && tar->Type==ST_ACTOR) {
+		if (Sender->Type==ST_ACTOR && tar->Type==ST_ACTOR && Sender!=tar) {
 			Actor* snd = ( Actor* ) Sender;
 			//additional checks for invisibility?
 			snd->LastSeen = tar->GetGlobalID();
@@ -816,12 +821,14 @@ void EscapeAreaCore(Scriptable* Sender, const Point &p, const char* area, const
 {
 	char Tmp[256];
 
-	if ( !p.isempty() && PersonalDistance(p, Sender)>MAX_OPERATING_DISTANCE) {
-		//MoveNearerTo will return 0, if the actor is in move
-		//it will return 1 (the fourth parameter) if the target is unreachable
-		if (!MoveNearerTo(Sender, p, MAX_OPERATING_DISTANCE,1) ) {
-			if(!Sender->InMove()) print("At least it said so...");
-			return;
+	if (Sender->CurrentActionTicks<100) {
+		if ( !p.isempty() && PersonalDistance(p, Sender)>MAX_OPERATING_DISTANCE) {
+			//MoveNearerTo will return 0, if the actor is in move
+			//it will return 1 (the fourth parameter) if the target is unreachable
+			if (!MoveNearerTo(Sender, p, MAX_OPERATING_DISTANCE,1) ) {
+				if(!Sender->InMove()) print("At least it said so...");
+				return;
+			}
 		}
 	}
 
@@ -1033,7 +1040,9 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 			break;
 		case BD_SOURCE:
 		case BD_TARGET:
-			if (swap) Dialog = scr->GetDialog();
+			// Don't check for the target being non-interruptible if we swapped speakers
+			// or if the speaker is the target, otherwise do (and request feedback on failure).
+			if (swap || speaker==target) Dialog = scr->GetDialog();
 			else Dialog = target->GetDialog(GD_FEEDBACK);
 			break;
 		case BD_RESERVED:
@@ -1071,17 +1080,12 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 		return;
 	}
 
-	//maybe we should remove the action queue, but i'm unsure
-	//no, we shouldn't even call this!
-	//Sender->ReleaseCurrentAction();
-
 	// moved this here from InitDialog, because InitDialog doesn't know which side is which
 	// post-swap (and non-actors always have IF_NOINT set) .. also added a check that it's
 	// actually busy doing something, for the same reason
-	// HACK: skip the check for StartDialog, since it makes no sense (breaks transition to hell)
 	Action *curact = target->GetCurrentAction();
-	if (target->GetInternalFlag()&IF_NOINT && ((curact && curact->actionID != 137) || \
-	(!curact && target->GetNextAction()))) {
+	if ((speaker != target) && (target->GetInternalFlag()&IF_NOINT) && \
+	  (!curact && target->GetNextAction())) {
 		core->GetTokenDictionary()->SetAtCopy("TARGET", target->GetName(1));
 		displaymsg->DisplayConstantString(STR_TARGETBUSY, DMC_RED);
 		Sender->ReleaseCurrentAction();
@@ -1163,29 +1167,27 @@ void MoveBetweenAreasCore(Actor* actor, const char *area, const Point &position,
 {
 	Log(MESSAGE, "GameScript", "MoveBetweenAreas: %s to %s [%d.%d] face: %d",
 		actor->GetName(0), area,position.x,position.y, face);
+	Map* map1 = actor->GetCurrentArea();
 	Map* map2;
 	Game* game = core->GetGame();
-	if (area[0]) { //do we need to switch area?
-		Map* map1 = actor->GetCurrentArea();
+	if (area[0] && (!map1 || stricmp(area, map1->GetScriptName()))) { //do we need to switch area?
 		//we have to change the pathfinder
 		//to the target area if adjust==true
 		map2 = game->GetMap(area, false);
-		if ( map1!=map2 ) {
-			if (map1) {
-				map1->RemoveActor( actor );
-			}
-			map2->AddActor( actor, true );
+		if (map1) {
+			map1->RemoveActor( actor );
+		}
+		map2->AddActor( actor, true );
 
-			// update the worldmap if needed
-			if (actor->InParty) {
-				WorldMap *worldmap = core->GetWorldMap();
-				unsigned int areaindex;
-				WMPAreaEntry *entry = worldmap->GetArea(area, areaindex);
-				if (entry) {
-					// make sure the area is marked as revealed and visited
-					if (!(entry->GetAreaStatus() & WMP_ENTRY_VISITED)) {
-						entry->SetAreaStatus(WMP_ENTRY_VISIBLE|WMP_ENTRY_VISITED, BM_OR);
-					}
+		// update the worldmap if needed
+		if (actor->InParty) {
+			WorldMap *worldmap = core->GetWorldMap();
+			unsigned int areaindex;
+			WMPAreaEntry *entry = worldmap->GetArea(area, areaindex);
+			if (entry) {
+				// make sure the area is marked as revealed and visited
+				if (!(entry->GetAreaStatus() & WMP_ENTRY_VISITED)) {
+					entry->SetAreaStatus(WMP_ENTRY_VISIBLE|WMP_ENTRY_VISITED, BM_OR);
 				}
 			}
 		}
@@ -1281,6 +1283,7 @@ bool CreateItemCore(CREItem *item, const char *resref, int a, int b, int c)
 void AttackCore(Scriptable *Sender, Scriptable *target, int flags)
 {
 	//this is a dangerous cast, make sure actor is Actor * !!!
+	assert(Sender && Sender->Type == ST_ACTOR);
 	Actor *actor = (Actor *) Sender;
 
 	WeaponInfo wi;
@@ -1294,9 +1297,20 @@ void AttackCore(Scriptable *Sender, Scriptable *target, int flags)
 	Actor *tar = NULL;
 	if (target->Type==ST_ACTOR) {
 		tar = (Actor *) target;
+
+		// release if target is invisible to sender (because of death or invisbility spell)
+		if (tar->IsInvisibleTo(Sender) || (tar->GetSafeStat(IE_STATE_ID) & STATE_DEAD)){
+			actor->SetStance(IE_ANI_READY);
+			Sender->ReleaseCurrentAction();
+			actor->AddTrigger(TriggerEntry(trigger_targetunreachable, tar->GetGlobalID()));
+			Log(WARNING, "AttackCore", "Tried attacking invisible/dead actor: %s!", tar->GetName(1));
+			return;
+		}
 	}
+
 	if (actor == tar) {
 		Sender->ReleaseCurrentAction();
+		Log(WARNING, "AttackCore", "Tried attacking itself: %s!", tar->GetName(1));
 		return;
 	}
 
@@ -1304,6 +1318,8 @@ void AttackCore(Scriptable *Sender, Scriptable *target, int flags)
 	if (!actor->GetCombatDetails(tohit, leftorright, wi, header, hittingheader, DamageBonus, speed, CriticalBonus, style, tar)) {
 		actor->SetStance(IE_ANI_READY);
 		Sender->ReleaseCurrentAction();
+		actor->AddTrigger(TriggerEntry(trigger_unusable, tar->GetGlobalID()));
+		Log(WARNING, "AttackCore", "Weapon unusable: %s!", actor->GetName(1));
 		return;
 	}
 
@@ -1325,11 +1341,11 @@ void AttackCore(Scriptable *Sender, Scriptable *target, int flags)
 		}
 	}
 	//action performed
-	actor->SetTarget( target );
+	actor->FaceTarget( target );
 
 	if ( Sender->GetCurrentArea()!=target->GetCurrentArea() ||
 		(PersonalDistance(Sender, target) > wi.range) ||
-		(!Sender->GetCurrentArea()->IsVisible(Sender->Pos, target->Pos))) {
+		(!Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, target->Pos))) {
 		MoveNearerTo(Sender, target, wi.range);
 		return;
 	} else if (target->Type == ST_DOOR) {
@@ -1415,6 +1431,13 @@ static void ParseObject(const char *&str,const char *&src, Object *&object)
 	SKIP_ARGUMENT();
 	object = new Object();
 	switch (*src) {
+	case ')':
+		// missing parameter
+		// (for example, StartDialogueNoSet() in aerie.d)
+		Log(WARNING, "GSUtils", "ParseObject expected an object when parsing dialog");
+		// replace with Myself
+		object->objectFilters[0] = 1;
+		break;
 	case '"':
 		//Scriptable Name
 		src++;
@@ -2254,6 +2277,81 @@ int GetGroup(Actor *actor)
 	return type;
 }
 
+Actor *GetNearestEnemyOf(Map *map, Actor *origin, int whoseeswho)
+{
+	//determining the allegiance of the origin
+	int type = GetGroup(origin);
+
+	//neutral has no enemies
+	if (type==2) {
+		return NULL;
+	}
+
+	Targets *tgts = new Targets();
+
+	int i = map->GetActorCount(true);
+	Actor *ac;
+	while (i--) {
+		ac=map->GetActor(i,true);
+		if (ac == origin) continue;
+
+		int distance = Distance(ac, origin);
+		if (whoseeswho&ENEMY_SEES_ORIGIN) {
+			if (!CanSee(ac, origin, true, GA_NO_DEAD)) {
+				continue;
+			}
+		}
+		if (whoseeswho&ORIGIN_SEES_ENEMY) {
+			if (!CanSee(ac, origin, true, GA_NO_DEAD)) {
+				continue;
+			}
+		}
+
+		if (type) { //origin is PC
+			if (ac->GetStat(IE_EA) >= EA_EVILCUTOFF) {
+				tgts->AddTarget(ac, distance, GA_NO_DEAD);
+			}
+		}
+		else {
+			if (ac->GetStat(IE_EA) <= EA_GOODCUTOFF) {
+				tgts->AddTarget(ac, distance, GA_NO_DEAD);
+			}
+		}
+	}
+	ac = (Actor *) tgts->GetTarget(0, ST_ACTOR);
+	delete tgts;
+	return ac;
+}
+
+Actor *GetNearestOf(Map *map, Actor *origin, int whoseeswho)
+{
+	Targets *tgts = new Targets();
+
+	int i = map->GetActorCount(true);
+	Actor *ac;
+	while (i--) {
+		ac=map->GetActor(i,true);
+		if (ac == origin) continue;
+
+		int distance = Distance(ac, origin);
+		if (whoseeswho&ENEMY_SEES_ORIGIN) {
+			if (!CanSee(ac, origin, true, GA_NO_DEAD)) {
+				continue;
+			}
+		}
+		if (whoseeswho&ORIGIN_SEES_ENEMY) {
+			if (!CanSee(ac, origin, true, GA_NO_DEAD)) {
+				continue;
+			}
+		}
+
+		tgts->AddTarget(ac, distance, GA_NO_DEAD);
+	}
+	ac = (Actor *) tgts->GetTarget(0, ST_ACTOR);
+	delete tgts;
+	return ac;
+}
+
 Point GetEntryPoint(const char *areaname, const char *entryname)
 {
 	Point p;
@@ -2555,7 +2653,7 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 	if (act) {
 		//move near to target
 		if ((flags&SC_RANGE_CHECK) && dist != 0xffffffff) {
-			if (PersonalDistance(tar, Sender) > dist || !Sender->GetCurrentArea()->IsVisible(Sender->Pos, tar->Pos)) {
+			if (PersonalDistance(tar, Sender) > dist || !Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, tar->Pos)) {
 				MoveNearerTo(Sender, tar, dist);
 				return;
 			}
@@ -2648,7 +2746,7 @@ void SpellPointCore(Scriptable *Sender, Action *parameters, int flags)
 
 		Actor *act = (Actor *) Sender;
 		//move near to target
-		if ((flags&SC_RANGE_CHECK) && (PersonalDistance(parameters->pointParameter, Sender) > dist || !Sender->GetCurrentArea()->IsVisible(Sender->Pos, parameters->pointParameter))) {
+		if ((flags&SC_RANGE_CHECK) && (PersonalDistance(parameters->pointParameter, Sender) > dist || !Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, parameters->pointParameter))) {
 			MoveNearerTo(Sender,parameters->pointParameter, dist, 0);
 			return;
 		}
