@@ -53,6 +53,7 @@ class StringBuffer;
 #define DS_AREA    128
 
 //verbal constant (bg2), we have a lookup table (vcremap) for other games
+#define VB_INITIALMEET 0
 #define VB_PANIC     1
 #define VB_HAPPY     2
 #define VB_UNHAPPY   3
@@ -524,7 +525,9 @@ struct TriggerLink {
 #define AF_INVALID      128
 #define AF_DIRECT       256 //this hack will transfer target from gamecontrol to object1 at compile time
 #define AF_ALIVE        512 //only alive actors can do this
-#define AF_INSTANT      1024
+#define AF_INSTANT      1024 //instant actions
+#define AF_CHASE        2048 // ??? actions involving movement ???
+#define AF_SLEEP        4096 //only awake actors can do this
 
 struct ActionLink {
 	const char* Name;
@@ -1482,6 +1485,7 @@ public:
 	static Targets *SixthNearestEnemyOf(Scriptable *Sender, Targets *parameters, int ga_flags);
 	static Targets *SixthNearestEnemyOfType(Scriptable *Sender, Targets *parameters, int ga_flags);
 	static Targets *SixthNearestMyGroupOfType(Scriptable *Sender, Targets *parameters, int ga_flags);
+	static Targets *SpellTarget(Scriptable *Sender, Targets *parameters, int ga_flags);
 	static Targets *StrongestOf(Scriptable *Sender, Targets *parameters, int ga_flags);
 	static Targets *StrongestOfMale(Scriptable *Sender, Targets *parameters, int ga_flags);
 	static Targets *TenthNearest(Scriptable *Sender, Targets *parameters, int ga_flags);
