@@ -62,6 +62,17 @@ static inline bool DoObjectIDSCheck(Object *oC, Actor *ac, bool *filtered) {
 
 /* do object filtering: Myself, LastAttackerOf(Player1), etc */
 static inline Targets *DoObjectFiltering(Scriptable *Sender, Targets *tgts, Object *oC, int ga_flags) {
+	targetlist::iterator m;
+	const targettype *tt = tgts->GetFirstTarget(m, ST_ACTOR);
+	while (tt) {
+		Actor *target = (Actor *) tt->actor;
+		if (target->ValidTarget(GA_NO_DEAD)) {
+			tt = tgts->GetNextTarget(m, ST_ACTOR);
+		} else {
+			tt = tgts->RemoveTargetAt(m);
+		}
+	}
+
 	for (int i = 0; i < MaxObjectNesting; i++) {
 		int filterid = oC->objectFilters[i];
 		if (!filterid) break;
@@ -96,21 +107,8 @@ static inline bool DoObjectChecks(Map *map, Scriptable *Sender, Actor *target, i
 		Actor *source = (Actor *)Sender;
 
 		// Detect() ignores invisibility completely
-		if (!ignoreinvis) {
-			// TODO: move this stuff into a shared function so it can be used elsewhere?
-
-			// SEEINVISIBLE skips these checks :-)
-			if (source->Modified[IE_SEEINVISIBLE] == 0) {
-				ieDword state = target->Modified[IE_STATE_ID];
-				// check for invisibility
-				if ((state & STATE_INVISIBLE) != 0) return false;
-				// check for improved invisibility? probably not
-				//if ((state & STATE_INVIS2) != 0) return false;
-			}
-
-			// maybe this should be setting an invis flag?
-			// TODO: should SEEINVISIBLE ignore this? Detect()?
-			if (target->Modified[IE_AVATARREMOVAL]) return false;
+		if (!ignoreinvis && target->IsInvisibleTo(source)) {
+			return false;
 		}
 
 		// visual range check
@@ -118,7 +116,7 @@ static inline bool DoObjectChecks(Map *map, Scriptable *Sender, Actor *target, i
 		if (dist > visualrange*visualrange) return false;
 
 		// LOS check
-		if (!map->IsVisible(Sender->Pos, target->Pos)) return false;
+		if (!map->IsVisibleLOS(Sender->Pos, target->Pos)) return false;
 
 		// protection against creature
 		if (target->fxqueue.HasEffect(fx_protection_creature_ref)) {
@@ -207,6 +205,8 @@ static Targets* EvaluateObject(Map *map, Scriptable* Sender, Object* oC, int ga_
 		if (ac == Sender) continue;
 		bool filtered = false;
 		if (DoObjectIDSCheck(oC, ac, &filtered)) {
+			// this is needed so eg. Range trigger gets a good object
+			// HACK: our parsing of Attack([0]) is broken
 			if (!filtered) {
 				// if no filters were applied..
 				assert(!tgts);
@@ -305,7 +305,7 @@ Scriptable* GetStoredActorFromObject(Scriptable* Sender, Object* oC, int ga_flag
 	// maybe store the target if it's an actor..
 	if (tar && tar->Type == ST_ACTOR) {
 		// .. but we only want objects created via objectFilters
-		if (oC->objectFilters[0]) {
+		if (oC && oC->objectFilters[0]) {
 			Sender->CurrentActionTarget = tar->GetGlobalID();
 		}
 	}
@@ -316,16 +316,13 @@ Scriptable* GetActorFromObject(Scriptable* Sender, Object* oC, int ga_flags)
 {
 	Scriptable *aC = NULL;
 
-	if (!oC) {
-		return NULL;
-	}
 	Game *game = core->GetGame();
 	Targets *tgts = GetAllObjects(Sender->GetCurrentArea(), Sender, oC, ga_flags);
 	if (tgts) {
 		//now this could return other than actor objects
 		aC = tgts->GetTarget(0,-1);
 		delete tgts;
-		if (aC || oC->objectFields[0]!=-1) {
+		if (aC || !oC || oC->objectFields[0]!=-1) {
 			return aC;
 		}
 
@@ -333,6 +330,10 @@ Scriptable* GetActorFromObject(Scriptable* Sender, Object* oC, int ga_flags)
 		return game->GetGlobalActorByGlobalID(oC->objectFields[1]);
 	}
 
+	if (!oC) {
+		return NULL;
+	}
+
 	if (oC->objectName[0]) {
 		// if you ActionOverride a global actor, they might not have a map :(
 		// TODO: don't allow this to happen?
@@ -639,12 +640,12 @@ Targets *XthNearestEnemyOfType(Scriptable *origin, Targets *parameters, unsigned
 		Actor *actor = (Actor *) (t->actor);
 		// IDS targeting already did object checks (unless we need to override Detect?)
 		if (type) { //origin is PC
-			if (actor->GetStat(IE_EA) <= EA_GOODCUTOFF) {
+			if (actor->GetStat(IE_EA) <= EA_EVILCUTOFF) {
 				t=parameters->RemoveTargetAt(m);
 				continue;
 			}
 		} else {
-			if (actor->GetStat(IE_EA) >= EA_EVILCUTOFF) {
+			if (actor->GetStat(IE_EA) >= EA_GOODCUTOFF) {
 				t=parameters->RemoveTargetAt(m);
 				continue;
 			}
@@ -672,6 +673,7 @@ Targets *XthNearestEnemyOf(Targets *parameters, int count, int ga_flags)
 	Actor *ac;
 	while (i--) {
 		ac=map->GetActor(i,true);
+		if (ac == origin) continue;
 		int distance;
 		//int distance = Distance(ac, origin);
 		// TODO: if it turns out you need to check Sender here, beware you take the right distance!
