@@ -29,6 +29,7 @@
 #include "SClassID.h"
 #include "exports.h"
 
+#include "Audio.h" // needed for _MSC_VER and SoundHandle (everywhere)
 #include "Cache.h"
 #include "Callback.h"
 #include "Holder.h"
@@ -38,7 +39,6 @@
 #include <vector>
 
 #ifdef _MSC_VER // No SFINAE
-#include "Audio.h"
 #include "DataFileMgr.h"
 #include "MusicMgr.h"
 #include "SaveGame.h"
@@ -150,6 +150,13 @@ struct SurgeSpell {
 	ieStrRef message;
 };
 
+// whitelist of config values we can push directly into vars
+struct INIWhiteListEntry {
+	const char* INITag;
+	const char* INIKey;
+	int defaultValue;
+};
+
 class ItemList {
 public:
 	ieResRef *ResRefs;
@@ -192,6 +199,7 @@ public:
 #define QF_CHANGESCRIPT  4
 #define QF_LOADGAME      8
 #define QF_ENTERGAME     16
+#define QF_KILL			32
 
 //events that are called out of drawwindow
 //they wait until the condition is right
@@ -345,6 +353,7 @@ private:
 	int tooltip_x;
 	int tooltip_y;
 	int tooltip_currtextw;
+	Holder<SoundHandle> tooltip_sound;
 	// the control owning the tooltip
 	Control* tooltip_ctrl;
 	// Currently dragged item or NULL
@@ -365,6 +374,7 @@ private:
 	int SpecialSpellsCount;
 	SpellDescType *SpecialSpells;
 	KeyMap *keymap;
+	std::string Encoding;
 public:
 	Holder<StringMgr> strings;
 	GlobalTimer * timer;
@@ -711,11 +721,15 @@ public:
 	int GetSpecialSpell(const ieResRef resref);
 	int GetSpecialSpellsCount() { return SpecialSpellsCount; }
 	SpellDescType *GetSpecialSpells() { return SpecialSpells; }
+	/** Saves config variables to a file */
+	bool SaveConfig();
 private:
 	int LoadSprites();
 	bool LoadConfig(void);
 	bool LoadConfig(const char *filename);
 	bool LoadGemRBINI();
+	/** Load the encoding table selected in gemrb.cfg */
+	bool LoadEncoding();
 	bool InitializeVarsWithINI(const char * iniFileName);
 	bool InitItemTypes();
 	bool ReadRandomItems();
@@ -792,8 +806,8 @@ public:
 	bool IsFreezed();
 	/** Draws the Visible windows in the Windows Array */
 	void DrawWindows(bool allow_delete = false);
-	/** Sends a termination signal to the Video Driver */
-	bool Quit(void);
+	void AskAndExit();
+	void ExitGemRB(void);
 	/** CheatKey support */
 	inline void EnableCheatKeys(int Flag)
 	{
