@@ -359,6 +359,7 @@ int Inventory::CountItems(const char *resref, bool stacks) const
 		}
 		if (stacks && (item->Flags&IE_INV_ITEM_STACKED) ) {
 			count+=item->Usages[0];
+			assert(count!=0);
 		}
 		else {
 			count++;
@@ -1464,8 +1465,12 @@ ieWord Inventory::GetShieldItemType() const
 {
 	ieWord ret;
 	CREItem *Slot;
+	int slotNum = GetShieldSlot();
 
-	const Item *itm = GetItemPointer(GetShieldSlot(), Slot);
+	if (slotNum < 0) {
+		return 0xffff;
+	}
+	const Item *itm = GetItemPointer(slotNum, Slot);
 	if (!itm) return 0xffff;
 	ret = itm->ItemType;
 	gamedata->FreeItem( itm, Slot->ItemResRef, true );
@@ -1476,8 +1481,12 @@ ieWord Inventory::GetArmorItemType() const
 {
 	ieWord ret;
 	CREItem *Slot;
+	int slotNum = GetArmorSlot();
 
-	const Item *itm = GetItemPointer(GetArmorSlot(), Slot);
+	if (slotNum < 0) {
+		return 0xffff;
+	}
+	const Item *itm = GetItemPointer(slotNum, Slot);
 	if (!itm) return 0xffff;
 	ret = itm->ItemType;
 	gamedata->FreeItem( itm, Slot->ItemResRef, true );
@@ -1547,6 +1556,10 @@ void Inventory::EquipBestWeapon(int flags)
 		for(i=SLOT_RANGED;i<LAST_RANGED;i++) {
 			const Item *itm = GetItemPointer(i, Slot);
 			if (!itm) continue;
+			//cannot change equipment when holding a cursed weapon
+			if (Slot->Flags & IE_INV_ITEM_CURSED) {
+				return;
+			}
 			//best ranged
 			int tmp = itm->GetDamagePotential(true, header);
 			if (tmp>damage) {
@@ -1562,6 +1575,10 @@ void Inventory::EquipBestWeapon(int flags)
 		for(i=SLOT_MELEE;i<=LAST_MELEE;i++) {
 			const Item *itm = GetItemPointer(i, Slot);
 			if (!itm) continue;
+			//cannot change equipment when holding a cursed weapon
+			if (Slot->Flags & IE_INV_ITEM_CURSED) {
+				return;
+			}
 			//best ranged
 			int tmp = itm->GetDamagePotential(true, header);
 			if (tmp>damage) {
@@ -1578,6 +1595,10 @@ void Inventory::EquipBestWeapon(int flags)
 		for(i=SLOT_MELEE;i<=LAST_MELEE;i++) {
 			const Item *itm = GetItemPointer(i, Slot);
 			if (!itm) continue;
+			//cannot change equipment when holding a cursed weapon
+			if (Slot->Flags & IE_INV_ITEM_CURSED) {
+				return;
+			}
 			//the Slot flag is enough for this
 			//though we need animation type/damagepotential anyway
 			if (Slot->Flags&IE_INV_ITEM_BOW) continue;
