@@ -528,11 +528,14 @@ void Map::MoveToNewArea(const char *area, const char *entrance, unsigned int dir
 		while (i--) {
 			Actor *pc = game->GetPC(i,false);
 			if (pc->GetCurrentArea()==this) {
-				pc->UseExit(0);
-				pc->ClearPath();
-				pc->ClearActions();
-				pc->AddAction( GenerateAction( command ) );
-				pc->ProcessActions();
+			  pc->MovementCommand(command);
+			}
+		}
+		i = game->GetNPCCount();
+		while(i--) {
+			Actor *npc = game->GetNPC(i);
+			if ((npc->GetCurrentArea()==this) && (npc->GetStat(IE_EA)<EA_GOODCUTOFF) ) {
+				npc->MovementCommand(command);
 			}
 		}
 		return;
@@ -546,20 +549,20 @@ void Map::MoveToNewArea(const char *area, const char *entrance, unsigned int dir
 				continue;
 			}
 			if (pc->GetCurrentArea()==this) {
-				pc->UseExit(0);
-				pc->ClearPath();
-				pc->ClearActions();
-				pc->AddAction( GenerateAction( command ) );
-				pc->ProcessActions();
+				pc->MovementCommand(command);
+			}
+		}
+		i = game->GetNPCCount();
+		while(i--) {
+			Actor *npc = game->GetNPC(i);
+			if (npc->IsSelected() && (npc->GetCurrentArea()==this)) {
+				npc->MovementCommand(command);
 			}
 		}
 		return;
 	}
 
-	actor->ClearPath();
-	actor->ClearActions();
-	actor->AddAction( GenerateAction( command ) );
-	actor->ProcessActions();
+	actor->MovementCommand(command);
 }
 
 void Map::UseExit(Actor *actor, InfoPoint *ip)
@@ -678,7 +681,6 @@ void Map::UpdateScripts()
 	if (!timestop) {
 		game->timestop_owner = NULL;
 	}
-	Actor *timestop_owner = game->timestop_owner;
 
 	while (q--) {
 		Actor* actor = queue[PR_SCRIPT][q];
@@ -689,7 +691,7 @@ void Map::UpdateScripts()
 		}
 
 		//FIXME:we need a better timestop hack, actors shouldn't abort moving after a timestop expired
-		if (timestop && actor!=timestop_owner && actor->Modified[IE_DISABLETIMESTOP] == 0) {
+		if (game->TimeStoppedFor(actor)) {
 			actor->no_more_steps = true;
 			actor->ClearPath(); //HACK: prevents jumping when timestop ends
 			continue;
@@ -1147,7 +1149,7 @@ void Map::DrawMap(Region screen)
 
 				Color tint = LightMap->GetPixel( sca->XPos / 16, sca->YPos / 12);
 				tint.a = 255;
-				bool endReached = sca->Draw(screen, Pos, tint, this, 0, -1);
+				bool endReached = sca->Draw(screen, Pos, tint, this, 0, -1, 0);
 				if (endReached) {
 					delete( sca );
 					scaidx=vvcCells.erase(scaidx);
@@ -1309,6 +1311,11 @@ void Map::Shout(Actor* actor, int shoutID, unsigned int radius)
 	while (i--) {
 		Actor *listener = actors[i];
 
+		// skip the shouter, so gpshout's InMyGroup(LastHeardBy(Myself)) can get two distinct actors
+		if (listener == actor) {
+			continue;
+		}
+
 		if (radius) {
 			if (Distance(actor->Pos, listener->Pos)>radius) {
 				continue;
@@ -1425,7 +1432,9 @@ void Map::AddActor(Actor* actor, bool init)
 {
 	//setting the current area for the actor as this one
 	strnlwrcpy(actor->Area, scriptName, 8);
-	actors.push_back( actor );
+	if (!HasActor(actor)) {
+		actors.push_back( actor );
+	}
 	if (init) {
 		actor->SetMap(this);
 		InitActor(actor);
@@ -1578,7 +1587,7 @@ Actor* Map::GetActorInRadius(const Point &p, int flags, unsigned int radius)
 }
 
 //maybe consider using a simple list
-Actor **Map::GetAllActorsInRadius(const Point &p, int flags, unsigned int radius)
+Actor **Map::GetAllActorsInRadius(const Point &p, int flags, unsigned int radius, Scriptable *see)
 {
 	ieDword count = 1;
 	size_t i;
@@ -1590,14 +1599,15 @@ Actor **Map::GetAllActorsInRadius(const Point &p, int flags, unsigned int radius
 
 		if (PersonalDistance( p, actor ) > radius)
 			continue;
-		if (!actor->ValidTarget(flags) ) {
+		if (!actor->ValidTarget(flags, see) ) {
 			continue;
 		}
 		if (!actor->Schedule(gametime, true) ) {
 			continue;
 		}
 		if (!(flags&GA_NO_LOS)) {
-			if (!IsVisible(actor->Pos, p)) {
+			//line of sight visibility
+			if (!IsVisibleLOS(actor->Pos, p)) {
 				continue;
 			}
 		}
@@ -1619,7 +1629,7 @@ Actor **Map::GetAllActorsInRadius(const Point &p, int flags, unsigned int radius
 			continue;
 		}
 		if (!(flags&GA_NO_LOS)) {
-			if (!IsVisible(actor->Pos, p)) {
+			if (!IsVisibleLOS(actor->Pos, p)) {
 				continue;
 			}
 		}
@@ -2167,6 +2177,8 @@ void Map::RemoveActor(Actor* actor)
 	size_t i=actors.size();
 	while (i--) {
 		if (actors[i] == actor) {
+			//clear previous walk path
+			actor->ClearPath();
 			ClearSearchMapFor(actor);
 			actor->SetMap(NULL);
 			actors.erase( actors.begin()+i );
@@ -2637,7 +2649,7 @@ PathNode* Map::FindPathNear(const Point &s, const Point &d, unsigned int size, u
 				// we are within the minimum distance of the goal
 				Point ourpos(x*16 + 8, y*12 + 6);
 				// sight check is *slow* :(
-				if (!sight || IsVisible(ourpos, d)) {
+				if (!sight || IsVisibleLOS(ourpos, d)) {
 					// we got all the way to a suitable goal!
 					goal = Point(x, y);
 					found_path = true;
@@ -2848,7 +2860,7 @@ bool Map::IsVisible(const Point &pos, int explored)
 }
 
 //point a is visible from point b (searchmap)
-bool Map::IsVisible(const Point &s, const Point &d)
+bool Map::IsVisibleLOS(const Point &s, const Point &d)
 {
 	int sX=s.x/16;
 	int sY=s.y/12;
@@ -3409,7 +3421,9 @@ bool Map::HasWeather()
 	if ((AreaType & (AT_WEATHER|AT_OUTDOOR) ) != (AT_WEATHER|AT_OUTDOOR) ) {
 		return false;
 	}
-	return true;
+	ieDword tmp = 1;
+	core->GetDictionary()->Lookup("Weather", tmp);
+	return !!tmp;
 }
 
 int Map::GetWeather()
@@ -3809,3 +3823,4 @@ void Map::SetBackground(const ieResRef &bgResRef, ieDword duration)
 }
 
 }
+
