@@ -425,7 +425,7 @@ public:
 	/** returns a saving throw */
 	bool GetSavingThrow(ieDword type, int modifier);
 	/** Returns true if the actor is targetable */
-	bool ValidTarget(int ga_flags) const;
+	bool ValidTarget(int ga_flags, Scriptable *checker = NULL) const;
 	/** Returns a Stat value */
 	ieDword GetStat(unsigned int StatIndex) const;
 	/** Returns a safe Stat value, one, that is not partially computed */
@@ -500,7 +500,7 @@ public:
 	/* receives undead turning message */
 	void Turn(Scriptable *cleric, ieDword turnlevel);
 	/* call this on gui selects */
-	void SelectActor();
+	void PlaySelectionSound();
 	/* call this when adding actions via gui */
 	void CommandActor();
 	/** handle panic and other involuntary actions that mess with scripting */
@@ -534,7 +534,7 @@ public:
 	/* check and perform a cleave movement */
 	void CheckCleave();
 	/* deals damage to this actor */
-	int Damage(int damage, int damagetype, Scriptable *hitter, int modtype=MOD_ADDITIVE, int critical=0);
+	int Damage(int damage, int damagetype, Scriptable *hitter, int modtype=MOD_ADDITIVE, int critical=0, int saveflags=0);
 	/* displays the damage taken and other details (depends on the game type) */
 	void DisplayCombatFeedback (unsigned int damage, int resisted, int damagetype, Scriptable *hitter);
 	/* play a random footstep sound */
@@ -599,8 +599,8 @@ public:
 	int GetAttackStyle() const;
 	/* adds the combatants to the attackers list */
 	void AttackedBy(Actor *actor);
-	/* sets target for immediate attack */
-	void SetTarget( Scriptable *actor);
+	/* reorients to face target (for immediate attack) */
+	void FaceTarget(Scriptable *actor);
 	/* returns the number of attacks (handles monk barehanded bonus) */
 	ieDword GetNumberOfAttacks() const;
 	/* starts combat round*/
@@ -795,6 +795,8 @@ public:
 	bool IsRacialEnemy(Actor* target) const;
 	/* checks whether the actor can stay in the current modal state */
 	bool ModalSpellSkillCheck();
+	/* check if this actor is seen by or seeing anyone */
+	bool SeeAnyOne(bool enemy, bool seen);
 	/* does all the game logic checks to see if the actor can hide */
 	bool TryToHide();
 	/* checks if the alignment matches one of the masking constants */
@@ -823,6 +825,11 @@ public:
 	/* returns the armor check penalty */
 	int GetArmorFailure() const;
 	bool IsDead() const;
+	bool IsInvisibleTo(Scriptable *checker) const;
+	int UpdateAnimationID(bool derived);
+	void MovementCommand(char *command);
+	/* shows hp/maxhp as overhead text */
+	void DisplayHeadHPRatio();
 };
 }
 
