@@ -51,6 +51,7 @@ namespace GemRB {
 
 // we start this at a non-zero value to make debugging easier
 static ieDword globalActorCounter = 10000;
+static bool startActive = false;
 
 /***********************
  *  Scriptable Class   *
@@ -105,7 +106,10 @@ Scriptable::Scriptable(ScriptableType type)
 
 	WaitCounter = 0;
 	if (Type == ST_ACTOR) {
-		InternalFlags = IF_ACTIVE | IF_VISIBLE | IF_USEDSAVE;
+		InternalFlags = IF_VISIBLE | IF_USEDSAVE;
+		if (startActive) {
+			InternalFlags |= IF_ACTIVE;
+		}
 	} else {
 		InternalFlags = IF_ACTIVE | IF_VISIBLE | IF_NOINT;
 	}
@@ -114,10 +118,7 @@ Scriptable::Scriptable(ScriptableType type)
 	Pos.y = 0;
 
 	LastSpellOnMe = 0xffffffff;
-	SpellHeader = -1;
-	SpellResRef[0] = 0;
-	LastTarget = 0;
-	LastTargetPos.empty();
+	ResetCastingState(NULL);
 	InterruptCasting = false;
 	locals = new Variables();
 	locals->SetType( GEM_VARIABLES_INT );
@@ -126,7 +127,7 @@ Scriptable::Scriptable(ScriptableType type)
 	AddTrigger(TriggerEntry(trigger_oncreation));
 
 	memset( script_timers,0, sizeof(script_timers));
-
+	startActive = core->HasFeature(GF_START_ACTIVE);
 }
 
 Scriptable::~Scriptable(void)
@@ -437,7 +438,9 @@ void Scriptable::AddAction(Action* aC)
 	}
 
 	InternalFlags|=IF_ACTIVE;
-	InternalFlags&=~IF_IDLE;
+	if (startActive) {
+		InternalFlags &= ~IF_IDLE;
+	}
 	aC->IncRef();
 	if (actionflags[aC->actionID] & AF_SCRIPTLEVEL) {
 		aC->int0Parameter = scriptlevel;
@@ -704,7 +707,6 @@ void Scriptable::CreateProjectile(const ieResRef SpellResRef, ieDword tgt, int l
 	int projectileCount = 1;
 	if (Type == ST_ACTOR) {
 		caster = (Actor *) this;
-		caster->CureInvisibility();
 		if (spl->Flags&SF_HOSTILE) {
 			caster->CureSanctuary();
 		}
@@ -895,7 +897,7 @@ void Scriptable::CreateProjectile(const ieResRef SpellResRef, ieDword tgt, int l
 
 void Scriptable::SendTriggerToAll(TriggerEntry entry)
 {
-	Actor** nearActors = area->GetAllActorsInRadius(Pos, GA_NO_DEAD, MAX_CIRCLE_SIZE*2*16);
+	Actor** nearActors = area->GetAllActorsInRadius(Pos, GA_NO_DEAD, 15*10);
 	int i=0;
 	while(nearActors[i]!=NULL) {
 		nearActors[i]->AddTrigger(entry);
@@ -904,6 +906,16 @@ void Scriptable::SendTriggerToAll(TriggerEntry entry)
 	free(nearActors);
 }
 
+inline void Scriptable::ResetCastingState(Actor *caster) {
+	SpellHeader = -1;
+	SpellResRef[0] = 0;
+	LastTarget = 0;
+	LastTargetPos.empty();
+	if (caster) {
+		memset(&(caster->wildSurgeMods), 0, sizeof(caster->wildSurgeMods));
+	}
+}
+
 void Scriptable::CastSpellPointEnd(int level, int no_stance)
 {
 	Actor *caster = NULL;
@@ -918,16 +930,15 @@ void Scriptable::CastSpellPointEnd(int level, int no_stance)
 		caster = ((Actor *) this);
 		if (!no_stance) {
 			caster->SetStance(IE_ANI_CONJURE);
+			caster->CureInvisibility();
 		}
-		if (level == 0) {
-			Actor *actor = NULL;
-			if (Type == ST_ACTOR) {
-				actor = (Actor *) this;
-				level = actor->GetCasterLevel(nSpellType);
-			} else {
-				//default caster level is 1
-				level = 1;
-			}
+	}
+	if (level == 0) {
+		if (caster) {
+			level = caster->GetCasterLevel(nSpellType);
+		} else {
+			//default caster level is 1
+			level = 1;
 		}
 	}
 
@@ -944,6 +955,11 @@ void Scriptable::CastSpellPointEnd(int level, int no_stance)
 	if (!SpellResRef[0]) {
 		return;
 	}
+	if (!area) {
+		Log(ERROR, "Scriptable", "CastSpellPointEnd: lost area, skipping %s!", SpellResRef);
+		ResetCastingState(caster);
+		return;
+	}
 
 	CreateProjectile(SpellResRef, 0, level, false);
 	//FIXME: this trigger affects actors whom the caster sees, not just the caster itself
@@ -961,13 +977,7 @@ void Scriptable::CastSpellPointEnd(int level, int no_stance)
 		break;
 	}
 
-	SpellHeader = -1;
-	SpellResRef[0] = 0;
-	LastTarget = 0;
-	LastTargetPos.empty();
-	if (caster) {
-		memset(&(caster->wildSurgeMods), 0, sizeof(caster->wildSurgeMods));
-	}
+	ResetCastingState(caster);
 }
 
 void Scriptable::CastSpellEnd(int level, int no_stance)
@@ -983,13 +993,15 @@ void Scriptable::CastSpellEnd(int level, int no_stance)
 		caster = ((Actor *) this);
 		if (!no_stance) {
 			caster->SetStance(IE_ANI_CONJURE);
+			caster->CureInvisibility();
 		}
-		if (level == 0) {
-			Actor *actor = NULL;
-			if (Type == ST_ACTOR) {
-				actor = (Actor *) this;
-				level = actor->GetCasterLevel(nSpellType);
-			}
+	}
+	if (level == 0) {
+		if (caster) {
+			level = caster->GetCasterLevel(nSpellType);
+		} else {
+			//default caster level is 1
+			level = 1;
 		}
 	}
 
@@ -1004,6 +1016,11 @@ void Scriptable::CastSpellEnd(int level, int no_stance)
 	if (!SpellResRef[0]) {
 		return;
 	}
+	if (!area) {
+		Log(ERROR, "Scriptable", "CastSpellEnd: lost area, skipping %s!", SpellResRef);
+		ResetCastingState(caster);
+		return;
+	}
 
 	//if the projectile doesn't need to follow the target, then use the target position
 	CreateProjectile(SpellResRef, LastTarget, level, GetSpellDistance(SpellResRef, this)==0xffffffff);
@@ -1029,13 +1046,7 @@ void Scriptable::CastSpellEnd(int level, int no_stance)
 		target->LastSpellOnMe = spellID;
 	}
 
-	SpellHeader = -1;
-	SpellResRef[0] = 0;
-	LastTarget = 0;
-	LastTargetPos.empty();
-	if (caster) {
-		memset(&(caster->wildSurgeMods), 0, sizeof(caster->wildSurgeMods));
-	}
+	ResetCastingState(caster);
 }
 
 // check for input sanity and good casting conditions
