@@ -24,8 +24,10 @@
 
 namespace GemRB {
 
-Logger::Logger()
-{}
+Logger::Logger(log_level level)
+{
+	SetLogLevel(level);
+}
 
 Logger::~Logger()
 {}
@@ -35,6 +37,32 @@ void Logger::destroy()
 	delete this;
 }
 
+bool Logger::SetLogLevel(log_level level)
+{
+	if (level > INTERNAL) {
+		myLevel = level;
+		static const char* fmt = "Log Level set to %d";
+		char msg[25];
+		snprintf(msg, 25, fmt, level);
+		// careful to use our log function and not the global one to prevent this message form
+		// propagating to other loggers.
+		LogInternal(INTERNAL, "Logger", msg, DEFAULT);
+		return true;
+	} else {
+		// careful to use our log function and not the global one to prevent this message form
+		// propagating to other loggers.
+		LogInternal(INTERNAL, "Logger", "Log Level cannot be set below CRITICAL.", RED);
+	}
+	return false;
+}
+
+void Logger::log(log_level level, const char* owner, const char* message, log_color color)
+{
+	if (level <= myLevel) {
+		LogInternal(level, owner, message, color);
+	}
+}
+
 const char* log_level_text[] = {
 	"FATAL",
 	"ERROR",
