@@ -377,7 +377,7 @@ int fx_transfer_hp (Scriptable* Owner, Actor* target, Effect* fx)
 		damage=(signed) fx->Parameter1;
 	}
 	if (damage) {
-		damage = donor->Damage(damage, fx->Parameter2, owner);
+		damage = donor->Damage(damage, fx->Parameter2, owner, fx->IsVariable, fx->SavingThrowType);
 		receiver->NewBase( IE_HITPOINTS, damage, MOD_ADDITIVE );
 	}
 	return FX_NOT_APPLIED;
