@@ -24,10 +24,6 @@
 #include "GUI/Console.h"
 #include "GUI/GameControl.h" // for TargetMode (contextual information for touch inputs)
 
-#ifdef ANDROID
-#include "SDL_screenkeyboard.h"
-#endif
-
 using namespace GemRB;
 
 //touch gestures
@@ -61,6 +57,8 @@ int SDL20VideoDriver::CreateDisplay(int w, int h, int b, bool fs, const char* ti
 {
 	bpp=b;
 	fullscreen=fs;
+	width = w, height = h;
+
 	Log(MESSAGE, "SDL 2 Driver", "Creating display");
 	Uint32 winFlags = SDL_WINDOW_SHOWN | SDL_WINDOW_OPENGL;
 #if TARGET_OS_IPHONE || ANDROID
@@ -77,7 +75,7 @@ int SDL20VideoDriver::CreateDisplay(int w, int h, int b, bool fs, const char* ti
 		//since we are in fullscreen this has no effect outside Android/iOS
 		winFlags |= SDL_WINDOW_BORDERLESS;
 	}
-	window = SDL_CreateWindow(title, SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, w, h, winFlags);
+	window = SDL_CreateWindow(title, SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, width, height, winFlags);
 	renderer = SDL_CreateRenderer(window, -1, 0);
 
 	if (renderer == NULL) {
@@ -85,14 +83,11 @@ int SDL20VideoDriver::CreateDisplay(int w, int h, int b, bool fs, const char* ti
 		return GEM_ERROR;
 	}
 
-#if TARGET_OS_IPHONE
-	// on iOS the window is always the entire screen
-	// simulate a window by making the using passed in values for the backBuf size
-	width = w;
-	height = h;
-#else
-	SDL_GetWindowSize(window, &width, &height);
-#endif
+	// we set logical size so that platforms where the window can be a diffrent size then requested
+	// function properly. eg iPhone and Android the requested size may be 640x480,
+	// but the window will always be the size of the screen
+	SDL_RenderSetLogicalSize(renderer, width, height);
+
 	Viewport.w = width;
 	Viewport.h = height;
 
@@ -113,7 +108,7 @@ void SDL20VideoDriver::InitMovieScreen(int &w, int &h, bool yuv)
 	SDL_RenderClear(renderer);
 
 	int winW, winH;
-	SDL_GetWindowSize(window, &winW, &winH);
+	SDL_RenderGetLogicalSize(renderer, &winW, &winH);
 
 	if (videoPlayer) SDL_DestroyTexture(videoPlayer);
 	if (yuv) {
@@ -161,7 +156,7 @@ void SDL20VideoDriver::showFrame(unsigned char* buf, unsigned int bufw,
 	if (g_truecolor) {
 		Uint16 *src = (Uint16*)buf;
 		for (row = 0; row < bufh; ++row) {
-			dst = (Uint32*)((Uint16*)pixels + row * pitch);
+			dst = (Uint32*)((Uint8*)pixels + row * pitch);
 			for (col = 0; col < bufw; ++col) {
 				color.r = ((*src & 0x7C00) >> 7) | ((*src & 0x7C00) >> 12);
 				color.g = ((*src & 0x03E0) >> 2) | ((*src & 0x03E0) >> 8);
@@ -276,19 +271,7 @@ int SDL20VideoDriver::SwapBuffers(void)
 		SDL_RenderFillRect(renderer, &dst);
 	}
 
-	int w, h = 0;
-	SDL_GetWindowSize(window, &w, &h);
-	SDL_Rect dstRect = {0, 0, w, h};
-#if TARGET_OS_IPHONE
-	// our "window" is simulated
-	if (!fullscreen) {
-		dstRect.x = (w - backBuf->w) / 2;
-		dstRect.y = (h - backBuf->h) / 2;
-		dstRect.w = backBuf->w;
-		dstRect.h = backBuf->h;
-	}
-#endif
-	SDL_RenderCopy(renderer, tex, NULL, &dstRect);
+	SDL_RenderCopy(renderer, tex, NULL, NULL);
 
 	SDL_RenderPresent( renderer );
 	SDL_DestroyTexture(tex);
@@ -345,29 +328,28 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 	 we need to get the scale factor to convert digitizer touch coordinates to screen pixel coordinates
 	 */
 	SDL_Touch *state = SDL_GetTouch(event.tfinger.touchId);
-	float xScaleFactor, yScaleFactor = 1.0;
-	int xOffset, yOffset = 0;
+	float xScaleFactor = 1.0, yScaleFactor = 1.0;
 	int numFingers = 0;
 	if(state){
 		focusCtrl = EvntManager->GetMouseFocusedControl();
 		numFingers = state->num_fingers;
-#if TARGET_OS_IPHONE
-		if (fullscreen) {
-			// simulated window adjustment
-			xScaleFactor = (state->xres / backBuf->w);
-			yScaleFactor = (state->yres / backBuf->h);
-		} else {
-#endif
+
 		int w, h;
-		SDL_GetWindowSize(window, &w, &h);
+		SDL_RenderGetLogicalSize(renderer, &w, &h);
 		xScaleFactor = (state->xres / w);
 		yScaleFactor = (state->yres / h);
-#if TARGET_OS_IPHONE
-			// now we need to offset the x/y coordinates
-			xOffset = ((w - backBuf->w) / 2) * -1;
-			yOffset = ((h - backBuf->h) / 2) * -1;
+		if (event.type == SDL_FINGERDOWN && numFingers > 1 && firstFingerDown.fingerId == 0) {
+			// this is a rare case where multiple fingers touch simultaniously (within the same tick)
+			// TODO: this is probably simulator only. if so lets ifdef it for the simulator
+
+			firstFingerDown.timestamp = GetTickCount();
+			firstFingerDown.x = (state->fingers[0]->x / xScaleFactor);
+			firstFingerDown.y = (state->fingers[0]->y / yScaleFactor);
+			firstFingerDown.dx = state->fingers[0]->xdelta / xScaleFactor;
+			firstFingerDown.dy = state->fingers[0]->ydelta / yScaleFactor;
+			firstFingerDown.fingerId = state->fingers[0]->id;
+			firstFingerDown.pressure = state->fingers[0]->pressure;
 		}
-#endif
 	}
 
 	bool ConsolePopped = core->ConsolePopped;
@@ -379,9 +361,11 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 		//  there is no way currently to use a mouse anyay.
 		//  watch future SDL releases to see if/when disabling mouse events from the touchscreen is available
 		//!!!!!!!!!!!!
-#if TARGET_OS_IPHONE
+#if TARGET_OS_IPHONE || ANDROID
+		// TODO: we shoud implement this as a preference so we can support mice on these platforms
+
 		// don't include SDL_MOUSEWHEEL here
-		// note that other platforms (non-iOS) needn't implement this
+		// note that other platforms needn't implement this
 		// and should let SDLVideo handle mouse events
 		case SDL_MOUSEMOTION:
 		case SDL_MOUSEBUTTONDOWN:
@@ -391,11 +375,12 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 		// For swipes only. gestures requireing pinch or rotate need to use SDL_MULTIGESTURE or SDL_DOLLARGESTURE
 		case SDL_FINGERMOTION:
 			ignoreNextFingerUp = true;
+			static SDL_TouchID lastFingerId = 0;
 
 			if (numFingers == core->NumFingScroll
 				|| (numFingers != core->NumFingKboard && (focusCtrl && focusCtrl->ControlType == IE_GUI_TEXTAREA))) {
 				//any # of fingers != NumFingKBoard will scroll a text area
-				if (focusCtrl->ControlType == IE_GUI_TEXTAREA) {
+				if (focusCtrl && focusCtrl->ControlType == IE_GUI_TEXTAREA) {
 					// if we are scrolling a text area we dont want the keyboard in the way
 					HideSoftKeyboard();
 				} else {
@@ -407,20 +392,22 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 				int scrollY = (event.tfinger.dy / yScaleFactor) * -1;
 
 				EvntManager->MouseWheelScroll( scrollX, scrollY );
-			} else if (numFingers == core->NumFingKboard) {
-				if ((event.tfinger.dy / yScaleFactor) * -1 >= MIN_GESTURE_DELTA_PIXELS){
+			} else if (numFingers == core->NumFingKboard && lastFingerId != state->fingers[0]->id) {
+				int delta = (int)(event.tfinger.dy / yScaleFactor) * -1;
+				if (delta > 0){
 					// if the keyboard is already up interpret this gesture as console pop
-					if( softKeyboardShowing && !ConsolePopped ) core->PopupConsole();
+					if( SDL_IsScreenKeyboardShown(window) && !ConsolePopped ) core->PopupConsole();
 					else ShowSoftKeyboard();
-				} else if((event.tfinger.dy / yScaleFactor) * -1 <= -MIN_GESTURE_DELTA_PIXELS){
+				} else if (delta < 0) {
 					HideSoftKeyboard();
 				}
 			} else if (numFingers == 1) { //click and drag
 				ProcessFirstTouch(GEM_MB_ACTION);
 				ignoreNextFingerUp = false;
 				// standard mouse movement
-				MouseMovement((event.tfinger.x / xScaleFactor) + xOffset, (event.tfinger.y / yScaleFactor) + yOffset);
+				MouseMovement((event.tfinger.x / xScaleFactor), (event.tfinger.y / yScaleFactor));
 			}
+			lastFingerId = state->fingers[0]->id;
 			break;
 		case SDL_FINGERDOWN:
 			if (numFingers == 1) {
@@ -428,9 +415,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 				firstFingerDown = event.tfinger;
 				firstFingerDownTime = GetTickCount();
 				firstFingerDown.x /= xScaleFactor;
-				firstFingerDown.x += xOffset;
 				firstFingerDown.y /= yScaleFactor;
-				firstFingerDown.y += yOffset;
 			} else if (EvntManager && numFingers == core->NumFingInfo) {
 				ProcessFirstTouch(GEM_MB_ACTION);
 				EvntManager->OnSpecialKeyPress( GEM_TAB );
@@ -450,11 +435,10 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 						CursorPos.x = event.button.x;
 						CursorPos.y = event.button.y;
 
-						EvntManager->MouseUp((event.tfinger.x / xScaleFactor) + xOffset,
-											 (event.tfinger.y / yScaleFactor) + yOffset,
+						EvntManager->MouseUp((event.tfinger.x / xScaleFactor),
+											 (event.tfinger.y / yScaleFactor),
 											 mouseButton, GetModState(SDL_GetModState()) );
 					}
-					ignoreNextFingerUp = false;
 				}
 				if (numFingers != core->NumFingInfo) {
 					// FIXME: this is "releasing" the ALT key even when it hadn't been previously "pushed"
@@ -549,13 +533,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 void SDL20VideoDriver::HideSoftKeyboard()
 {
 	if(core->UseSoftKeyboard){
-#if TARGET_OS_IPHONE
-		SDL_iPhoneKeyboardHide(window);
-#endif
-#ifdef ANDROID
-		SDL_ANDROID_SetScreenKeyboardShown(0);
-#endif
-		softKeyboardShowing = false;
+		SDL_HideScreenKeyboard(window);
 		if(core->ConsolePopped) core->PopupConsole();
 	}
 }
@@ -566,13 +544,7 @@ void SDL20VideoDriver::HideSoftKeyboard()
 void SDL20VideoDriver::ShowSoftKeyboard()
 {
 	if(core->UseSoftKeyboard){
-#if TARGET_OS_IPHONE
-		SDL_iPhoneKeyboardShow(window);
-#endif
-#ifdef ANDROID
-		SDL_ANDROID_SetScreenKeyboardShown(1);
-#endif
-		softKeyboardShowing = true;
+		SDL_ShowScreenKeyboard(window);
 	}
 }
 
@@ -589,7 +561,11 @@ void SDL20VideoDriver::SetGamma(int brightness, int /*contrast*/)
 
 bool SDL20VideoDriver::SetFullscreenMode(bool set)
 {
-	return (SDL_SetWindowFullscreen(window, (SDL_bool)set) == 0);
+	if (SDL_SetWindowFullscreen(window, (SDL_bool)set) == GEM_OK) {
+		fullscreen = set;
+		return true;
+	}
+	return false;
 }
 
 bool SDL20VideoDriver::ToggleGrabInput()
