@@ -150,8 +150,9 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 	switch (event.type) {
 			/* Process the appropriate event type */
 		case SDL_QUIT:
-			/* Handle a QUIT event */
-			return GEM_ERROR;
+			/* Quit event originated from outside GemRB so ask the user if we should exit */
+			core->AskAndExit();
+			return GEM_OK;
 			break;
 		case SDL_KEYUP:
 			switch(event.key.keysym.sym) {
@@ -495,66 +496,6 @@ Sprite2D* SDLVideoDriver::DuplicateSprite(const Sprite2D* sprite)
 	return dest;
 }
 
-// Note: BlitSpriteRegion's clip region is shifted by Viewport.x/y if
-// anchor is false. This is different from the other BlitSprite functions.
-void SDLVideoDriver::BlitSpriteRegion(const Sprite2D* spr, const Region& size, int x,
-	int y, bool anchor, const Region* clip)
-{
-	if (!spr->vptr) return;
-
-	// Adjust the clipping rect to match the region to blit, and then
-	// let BlitSprite handle the rest
-
-
-	Region c;
-
-	if (clip) {
-		c = *clip;
-		if (!anchor) {
-			c.x -= Viewport.x;
-			c.y -= Viewport.y;
-		}
-	} else {
-		c.x = 0;
-		c.y = 0;
-		c.w = backBuf->w;
-		c.h = backBuf->h;
-	}
-
-
-	Region dest;
-	dest.x = x - spr->XPos;
-	dest.y = y - spr->YPos;
-	if (!anchor) {
-		dest.x -= Viewport.x;
-		dest.y -= Viewport.y;
-	}
-
-	dest.w = size.w;
-	dest.h = size.h;
-
-	// c is the clipping rect, dest the unclipped destination rect
-	// We clip c to dest, and pass the resulting c to BlitSprite
-	if (dest.x > c.x) {
-		c.w -= (dest.x - c.x);
-		c.x = dest.x;
-	}
-	if (dest.y > c.y) {
-		c.h -= (dest.y - c.y);
-		c.y = dest.y;
-	}
-	if (c.x+c.w > dest.x+dest.w) {
-		c.w = dest.x+dest.w-c.x;
-	}
-	if (c.y+c.h > dest.y+dest.h) {
-		c.h = dest.y+dest.h-c.y;
-	}
-
-	if (c.w <= 0 || c.h <= 0) return;
-
-	BlitSprite(spr, x - size.x, y - size.y, anchor, &c);
-}
-
 void SDLVideoDriver::BlitTile(const Sprite2D* spr, const Sprite2D* mask, int x, int y, const Region* clip, unsigned int flags)
 {
 	if (spr->BAM) {
@@ -685,7 +626,7 @@ void SDLVideoDriver::BlitTile(const Sprite2D* spr, const Sprite2D* mask, int x,
 
 
 void SDLVideoDriver::BlitSprite(const Sprite2D* spr, int x, int y, bool anchor,
-	const Region* clip)
+	const Region* clip, Palette* palette)
 {
 	if (!spr->vptr) return;
 
@@ -740,7 +681,15 @@ void SDLVideoDriver::BlitSprite(const Sprite2D* spr, int x, int y, bool anchor,
 			srect = &t;
 
 		}
-		SDL_BlitSurface( ( SDL_Surface * ) spr->vptr, srect, backBuf, &drect );
+		if (palette) {
+			Palette* tmpPal = spr->GetPalette();
+			SetSurfacePalette(( SDL_Surface * )spr->vptr, (SDL_Color*)palette->col, 256);
+			SDL_BlitSurface( ( SDL_Surface * ) spr->vptr, srect, backBuf, &drect );
+			SetSurfacePalette(( SDL_Surface * )spr->vptr, (SDL_Color*)tmpPal->col, 256);
+			tmpPal->Release();
+		} else {
+			SDL_BlitSurface( ( SDL_Surface * ) spr->vptr, srect, backBuf, &drect );
+		}
 	} else {
 		Sprite2D_BAM_Internal* data = (Sprite2D_BAM_Internal*)spr->vptr;
 
@@ -753,20 +702,21 @@ void SDLVideoDriver::BlitSprite(const Sprite2D* spr, int x, int y, bool anchor,
 
 		SDL_LockSurface(backBuf);
 
+		Palette* pal = (palette) ? palette : data->pal;
 		SRShadow_Regular shadow;
 
-		if (data->pal->alpha) {
+		if (pal->alpha) {
 			SRTinter_NoTint<true> tinter;
 			SRBlender_Alpha blender;
 
 			BlitSpritePAL_dispatch(false, data->flip_hor,
-			    backBuf, srcdata, data->pal->col, tx, ty, spr->Width, spr->Height, data->flip_ver, finalclip, (Uint8)data->transindex, 0, spr, 0, shadow, tinter, blender);
+			    backBuf, srcdata, pal->col, tx, ty, spr->Width, spr->Height, data->flip_ver, finalclip, (Uint8)data->transindex, 0, spr, 0, shadow, tinter, blender);
 		} else {
 			SRTinter_NoTint<false> tinter;
 			SRBlender_NoAlpha blender;
 
 			BlitSpritePAL_dispatch(false, data->flip_hor,
-			    backBuf, srcdata, data->pal->col, tx, ty, spr->Width, spr->Height, data->flip_ver, finalclip, (Uint8)data->transindex, 0, spr, 0, shadow, tinter, blender);
+			    backBuf, srcdata, pal->col, tx, ty, spr->Width, spr->Height, data->flip_ver, finalclip, (Uint8)data->transindex, 0, spr, 0, shadow, tinter, blender);
 		}
 
 		SDL_UnlockSurface(backBuf);
@@ -1054,16 +1004,10 @@ Sprite2D* SDLVideoDriver::GetScreenshot( Region r )
 	unsigned int Height = r.h ? r.h : disp->h;
 	SDL_Rect src = {(Sint16)r.x, (Sint16)r.y, (Uint16)r.w, (Uint16)r.h};
 
-
-	SDL_Surface* surf = SDL_CreateRGBSurface( SDL_SWSURFACE, Width, Height, 24,
-				0xFF0000, 0x00FF00, 0x0000FF, 0x000000 );
-	SDL_BlitSurface( backBuf, (r.w && r.h) ? &src : NULL, surf, NULL);
 	void* pixels = malloc( Width * Height * 3 );
-	for (unsigned int y = 0; y < Height; y++)
-		memcpy( (char*)pixels+(Width * y * 3), (char*)surf->pixels+(surf->pitch * y), Width * 3 );
-	//freeing up temporary surface as we copied its pixels
 	Sprite2D* screenshot = CreateSprite( Width, Height, 24, 0x00ff0000, 0x0000ff00, 0x000000ff, 0x00000000, pixels, false, 0 );
-	SDL_FreeSurface(surf);
+	SDL_BlitSurface( backBuf, (r.w && r.h) ? &src : NULL, (SDL_Surface*)screenshot->vptr, NULL);
+
 	return screenshot;
 }
 
@@ -1672,18 +1616,6 @@ void SDLVideoDriver::DrawPolyline(Gem_Polygon* poly, const Color& color, bool fi
 	return;
 }
 
-/** Send a Quit Signal to the Event Queue */
-bool SDLVideoDriver::Quit()
-{
-	SDL_Event evtQuit = SDL_Event();
-
-	evtQuit.type = SDL_QUIT;
-	if (SDL_PushEvent( &evtQuit ) == -1) {
-		return false;
-	}
-	return true;
-}
-
 Palette* SDLVideoDriver::GetPalette(void *vptr)
 {
 	SDL_Surface* s = ( SDL_Surface* ) vptr;
